@@ -35,8 +35,7 @@
 #-------------------------------------------------------------------------
 #END_LICENSE
 
-$cgextensions = cms_join_path($gCms->config['root_path'],'modules',
-			      'CGExtensions','CGExtensions.module.php');
+$cgextensions = cms_join_path($gCms->config['root_path'],'modules','CGExtensions','CGExtensions.module.php');
 if( !is_readable( $cgextensions ) )
 {
   echo '<h1><font color="red">ERROR: The CGExtensions module could not be found.</font></h1>';
@@ -55,18 +54,13 @@ define('PRODUCTS_PREF_DFLTBYHIERARCHY_TEMPLATE','products_pref_dfltbyhierarchy_t
 define('PRODUCTS_PREF_NEWSEARCH_TEMPLATE','products_pref_newsearch_template');
 define('PRODUCTS_PREF_DFLTSEARCH_TEMPLATE','products_pref_dfltsearch_template');
 
-class Products extends CGExtensions
+final class Products extends CGExtensions
 {
-  var $_hierarchy_cache;
-  var $_category_cache;
   var $_admin_loaded;
-  var $_flddef_cache;
 
   public function __construct()
   {
     parent::__construct();
-	$this->_hierarchy_cache = array();
-	$this->_category_cache = array();
 	$this->_admin_loaded = false;
 
 	$this->AddImageDir('icons');
@@ -80,56 +74,35 @@ class Products extends CGExtensions
 							   array($this,'_smarty_products_hierarchy_parent'));
   }
 
-  function GetName()
-  {
-	return 'Products';
-  }
-
-  function GetFriendlyName()
-  {
-	return $this->Lang('product_manager');
-  }
+  public function GetName() { return 'Products'; }
+  public function GetFriendlyName() { return $this->Lang('product_manager'); }
+  public function AllowAutoInstall() { return FALSE; }
+  public function AllowAutoUpgrade() { return FALSE; }
+  public function IsPluginModule() { return true; }
+  public function HasAdmin() {	return true; }
+  public function GetVersion() { return '2.19.4'; }
+  public function MinimumCMSVersion() { return '1.11.4'; }
+  public function GetAdminDescription() { return $this->Lang('module_description'); }
+  public function UninstallPostMessage() { return $this->Lang('postuninstall'); }
+  public function UninstallPreMessage() { return $this->Lang('preuninstall'); }
+  public function GetHelp() {	return file_get_contents(__DIR__.'/help.inc'); }
+  public function GetAdminSection() { return 'content'; }
+  public function GetAuthor() { return 'calguy1000'; }
+  public function GetAuthorEmail() { return 'calguy1000@cmsmadesimple.org'; }
+  public function GetChangeLog() { return file_get_contents(__DIR__.'/changelog.html'); }
+  public function GetEventDescription( $eventname ) { return $this->lang('eventdesc-' . $eventname); }
+  public function GetEventHelp( $eventname ) {	return $this->lang('eventhelp-' . $eventname); }
+  public function HandlersEvents() { return TRUE; }
+  public function AllowSmartyCaching() { return TRUE; }
+  public function LazyLoadFrontend() { return FALSE; }  
+  public function LazyLoadAdmin() { return TRUE; }
+  public function InstallPostMessage() { return $this->Lang('postinstall'); }
 
   function GetDependencies()
   {
-	return array('CGExtensions'=>'1.24',
-				 'CGSimpleSmarty'=>'1.4.4',
-				 'JQueryTools'=>'1.0.11');
-  }
-
-  function AllowAutoInstall()
-  {
-	return FALSE;
-  }
-
-  function AllowAutoUpgrade()
-  {
-	return FALSE;
-  }
-
-  function IsPluginModule()
-  {
-	return true;
-  }
-
-  function HasAdmin()
-  {
-	return true;
-  }
-
-  function GetVersion()
-  {
-	return '2.18.4';
-  }
-
-  function MinimumCMSVersion()
-  {
-	return '1.10.2';
-  }
-
-  function GetAdminDescription()
-  {
-	return $this->Lang('module_description');
+	return array('CGExtensions'=>'1.32.5',
+				 'CGSimpleSmarty'=>'1.6.1',
+				 'JQueryTools'=>'1.2.4');
   }
 
   function VisibleToAdminUser()
@@ -139,23 +112,18 @@ class Products extends CGExtensions
 	  $this->CheckPermission('Modify Site Preferences');
   }
 
-  /*---------------------------------------------------------
-   GetHeaderHTML()
-   ---------------------------------------------------------*/
   function GetHeaderHTML()
   {
-	$obj = cge_utils::get_module('JQueryTools');
-    if( is_object($obj) )
-      {
+	$obj = cge_utils::get_module('JQueryTools','1.2');
+    if( is_object($obj) ) {
 $tmpl = <<<EOT
-{JQueryTools action='incjs' exclude='form'}
-{JQueryTools action='ready'}
+{JQueryTools action='require' lib='tablesorter,jquerytools'}
+{JQueryTools action='placemarker'}
 EOT;
         return $this->ProcessTemplateFromData($tmpl);
       }
   }	
 
-
   function SetParameters()
   {
 	$this->RegisterModulePlugin();
@@ -191,8 +159,6 @@ EOT;
 	$this->SetParameterType('sortorder',CLEAN_STRING);
 	$this->CreateParameter('sorttype','',$this->Lang('param_sorttype'));
 	$this->SetParameterType('sorttype',CLEAN_STRING);
-// 	$this->CreateParameter('selectcategory',0,$this->Lang('param_selectcategory'));
-// 	$this->SetParameterType('selectcategory',CLEAN_INT);
 	
 	$this->CreateParameter('excludecat','',$this->Lang('param_excludecat'));
 	$this->SetParameterType('excludecat',CLEAN_STRING);
@@ -246,19 +212,17 @@ EOT;
 
 	// Friendly URL stuff
     $detailpage = $this->GetPreference('detailpage',-1);
-	$contentops = cmsms()->GetContentOperations();
-    if( $detailpage == -1 )
-      {
-		$detailpage = $contentops->GetDefaultPageID();
-      }
+    if( $detailpage == -1 ) {
+	  $contentops = cmsms()->GetContentOperations();
+	  $detailpage = $contentops->GetDefaultPageID();
+	}
 	$str = '/'.$this->GetPreference('urlprefix','[Pp]roducts');
-	if( $this->GetPreference('usehierpathurls') )
-	  {
-		$this->RegisterRoute($str.'\/details\/(?P<returnid>[0-9]+)\/([^\/]+\/)+(?P<alias>.*)$/',
-							 array('action'=>'details','returnid'=>$detailpage));
-		$this->RegisterRoute($str.'\/details\/([^\/]+\/)+(?P<alias>.*)$/',
-							 array('action'=>'details','returnid'=>$detailpage));
-	  }
+	if( $this->GetPreference('usehierpathurls') ) {
+	  $this->RegisterRoute($str.'\/details\/(?P<returnid>[0-9]+)\/([^\/]+\/)+(?P<alias>.*)$/',
+						   array('action'=>'details','returnid'=>$detailpage));
+	  $this->RegisterRoute($str.'\/details\/([^\/]+\/)+(?P<alias>.*)$/',
+						   array('action'=>'details','returnid'=>$detailpage));
+	}
 
 	$this->RegisterRoute($str.'\/(?P<productid>[0-9]+)\/(?P<returnid>[0-9]+)\/(?P<junk>.*?)$/',
 						 array('action'=>'details'));
@@ -275,78 +239,15 @@ EOT;
 	$this->RegisterRoute($str.'\/byhierarchy\/(?P<hierarchyid>[0-9]+)\/(?P<returnid>[0-9]+)$/');
 
 	$hierpage = $this->GetPreference('hierpage',-1);
-	if( $hierpage <= 0 )
-	  {
-		$hierpage = $detailpage;
-	  }
+	if( $hierpage <= 0 ) {
+	  $hierpage = $detailpage;
+	}
 	$this->RegisterRoute($str.'\/hierarchy\/(?P<parent>[0-9]+)\/(?P<returnid>[0-9]+)$/');
 	$this->RegisterRoute($str.'\/hierarchy\/(?P<parent>[0-9]+)\/(?P<returnid>[0-9]+)\/(?P<junk>.*?)$/');
 	$this->RegisterRoute($str.'\/hierarchy\/(?P<parent>[0-9]+)\/(?P<junk>.*?)$/',
 						 array('action'=>'hierarchy','returnid'=>$hierpage));
   }
 
-  public function LazyLoadFrontend() { return FALSE; }  
-  public function LazyLoadAdmin() { return TRUE; }
-
-  function InstallPostMessage()
-  {
-	return $this->Lang('postinstall');
-  }
-
-  function UninstallPostMessage()
-  {
-	return $this->Lang('postuninstall');
-  }
-
-  function UninstallPreMessage()
-  {
-	return $this->Lang('preuninstall');
-  }
-
-  function GetHelp($lang='en_US')
-  {
-	return file_get_contents(dirname(__FILE__).'/help.inc');
-  }
-
-  function GetAdminSection()
-  {
-	return 'content';
-  }
-
-  function GetAuthor()
-  {
-	return 'calguy1000';
-  }
-
-  function GetAuthorEmail()
-  {
-	return 'calguy1000@cmsmadesimple.org';
-  }
-
-  function GetChangeLog()
-  {
-	return file_get_contents(dirname(__FILE__).'/changelog.html');
-  }
-
-  function GetEventDescription( $eventname )
-  {
-	return $this->lang('eventdesc-' . $eventname);
-  }
-
-  function GetEventHelp( $eventname )
-  {
-	return $this->lang('eventhelp-' . $eventname);
-  }
-
-  function HandlersEvents()
-  {
-	return TRUE;
-  }
-
-
-  /*---------------------------------------------------------
-   DoAction()
-   ---------------------------------------------------------*/
   function DoAction($name,$id,$params,$returnid='')
   {
     $smarty = cmsms()->GetSmarty();
@@ -356,25 +257,21 @@ EOT;
     parent::DoAction($name,$id,$params,$returnid);
   }
 
-
-  function _load_admin()
+  protected function _load_admin()
   {
-	if( !$this->_admin_loaded )
-	  {
-		require_once(dirname(__FILE__).'/functions.admin_tools.php');
-		$this->_admin_loaded = true;
-	  }
+	if( !$this->_admin_loaded ) {
+	  require_once(__DIR__.'/functions.admin_tools.php');
+	  $this->_admin_loaded = true;
+	}
   }
 
-
   // deprecated
-  function GetTypesDropdown( $id, $name, $selected = '', $addtext = '', $selectone = false )
+  protected function GetTypesDropdown( $id, $name, $selected = '', $addtext = '', $selectone = false )
   {
 	$this->_load_admin();
 	return products_GetTypesDropdown($this,$id,$name,$selected,$addtext,$selectone);
   }
 	
-
   // deprecated
   function &GetCategory($category_id,$full = false)
   {
@@ -395,19 +292,16 @@ EOT;
 	$onerow->value = false;
 	$onerow->file_location = $config['uploads_url'].'/'.$this->GetName().'/categories/'.$onerow->id;
 
-	if( $full )
-	  {
-		$tmp2 = $db->GetArray($query2,$row['id']);
-		if( is_array($tmp2) )
-		  {
-			$onerow->data = $tmp2;
-		  }
+	if( $full ) {
+	  $tmp2 = $db->GetArray($query2,$row['id']);
+	  if( is_array($tmp2) ) {
+		$onerow->data = $tmp2;
 	  }
+	}
 
 	return $onerow;
   }
 
-
   // deprecated
   function GetCategories($full = false)
   {
@@ -415,7 +309,6 @@ EOT;
 	return product_utils::get_categories($full);
   }
 
-
   // deprecated
   function GetCategoriesForProduct($product,$brief = false,$full = false)
   {
@@ -430,52 +323,41 @@ EOT;
 	$prodcats = $db->GetArray($query,array($product));
 	
 	$results = array();
-	if( $brief )
-	  {
-		foreach( $prodcats as $oneprodcat )
-		  {
-			foreach( $entryarray as $entry )
-			  {
-				if( $oneprodcat['category_id'] == $entry->id )
-				  {
-					$entry->value = true;
-					$results[] = $entry;
-					break;
-				  }
-			  }
-		  }
-	  }
-	else
-	  {
-		// full list of categories,
-		// set value to true if this product is a member of this category
-		foreach( $entryarray as $entry )
-		  {
-			$entry->value = false;
-			foreach( $prodcats as $oneprodcat )
-			  {
-				if( $oneprodcat['category_id'] == $entry->id )
-				  {
-					$entry->value = true;
-					break;
-				  }
-				
-			  }
-
+	if( $brief ) {
+	  foreach( $prodcats as $oneprodcat ) {
+		foreach( $entryarray as $entry ) {
+		  if( $oneprodcat['category_id'] == $entry->id ) {
+			$entry->value = true;
 			$results[] = $entry;
+			break;
 		  }
+		}
 	  }
+	}
+	else {
+	  // full list of categories,
+	  // set value to true if this product is a member of this category
+	  foreach( $entryarray as $entry ) {
+		$entry->value = false;
+		foreach( $prodcats as $oneprodcat ) {
+		  if( $oneprodcat['category_id'] == $entry->id ) {
+			$entry->value = true;
+			break;
+		  }
+		}
+
+		$results[] = $entry;
+	  }
+	}
 	return $results;
   }
 	
-
   // deprecated
   function GetFieldDefs($admin = false,$public = true)
   {
 	return product_utils::get_fielddefs($admin,$public);
   }
 
-
   // deprecated, move to class
   function GetFieldDefsForProduct($id,$admin = false,$public = true)
   {
@@ -485,61 +367,52 @@ EOT;
 	$entryarray = $this->GetFieldDefs($admin,$public);
 
 	$query = '';
-	if( $admin == true && $public == true )
-	  {
-		$query = 'SELECT fv.* FROM '.cms_db_prefix().'module_products_fieldvals fv WHERE fv.product_id = ?';
-	  }
-	else if( $public == true )
-	  {
-		$query = 'SELECT b.* FROM '.cms_db_prefix().'module_products_fielddefs a, '.cms_db_prefix().'module_products_fieldvals b WHERE a.id = b.fielddef_id AND a.public > 0 and b.product_id = ?';
-	  }
-	else 
-	  {
-		$query = 'SELECT b.* FROM  '.cms_db_prefix().'module_products_fielddefs a, '.cms_db_prefix().'module_products_fieldvals b WHERE a.id = b.fielddef_id AND a.admin_only <= 0 and b.product_id = ?';
-	  }
+	if( $admin == true && $public == true ) {
+	  $query = 'SELECT fv.* FROM '.cms_db_prefix().'module_products_fieldvals fv WHERE fv.product_id = ?';
+	}
+	else if( $public == true ) {
+	  $query = 'SELECT b.* FROM '.cms_db_prefix().'module_products_fielddefs a, '.cms_db_prefix().'module_products_fieldvals b WHERE a.id = b.fielddef_id AND a.public > 0 and b.product_id = ?';
+	}
+	else {
+	  $query = 'SELECT b.* FROM  '.cms_db_prefix().'module_products_fielddefs a, '.cms_db_prefix().'module_products_fieldvals b WHERE a.id = b.fielddef_id AND a.admin_only <= 0 and b.product_id = ?';
+	}
 	$dbresult = $db->GetArray($query, array($id));
 
 	$res = array();
-	foreach( $entryarray as $entry )
-	  {
-		$newentry = clone $entry;
-		$newentry->value = null;
-		foreach ($dbresult as $row)
-		  {
-			if ($row['fielddef_id'] == $newentry->id)
-			  {
-				if( $newentry->type == 'dimensions' || $newentry->type == 'subscription')
-				  {
-					$row['value'] = unserialize($row['value']);
-				  }
-				$newentry->value = $row['value'];
-				$newentry->fielddef_id = $newentry->id; // ??
-
-				break;
-			  }
+	if( is_array($entryarray) && count($entryarray) ) {
+	  foreach( $entryarray as $entry ) {
+	    $newentry = clone $entry;
+	    $newentry->value = null;
+	    foreach ($dbresult as $row) {
+		  if ($row['fielddef_id'] == $newentry->id) {
+			if( $newentry->type == 'dimensions' || $newentry->type == 'subscription') {
+			  $row['value'] = unserialize($row['value']);
+			}
+			$newentry->value = $row['value'];
+			$newentry->fielddef_id = $newentry->id; // ??
+			break;
 		  }
-		$res[] = $newentry;
+	    }
+	    $res[] = $newentry;
 	  }
+	}
 
 	return $res;
   }
 	
-
   function SearchResult($returnid, $productid, $attr = '')
   {
 	return product_ops::get_search_result($returnid,$productid,$attr);
   }
 	
-
   function SearchReindex(&$module)
   {
 	$this->_load_admin();
 	return products_SearchReindex($this,$module);
   }
 
-
   // deprecated ... move to class
-  function GetSearchableText($product_id)
+  protected function GetSearchableText($product_id)
   {
 	// the product name, the description, and all data from
 	// text fields, textara fields, and dropdowns
@@ -552,25 +425,20 @@ EOT;
 	$results[] = $product['details'];
 	$results[] = $product['sku'];
 	$results[] = $product['alias'];
-	foreach( $defs as $onedef )
-	  {
-		switch( $onedef->type )
-		  {
-		  case 'textbox':
-		  case 'textarea':
-		  case 'dropdown':
-            if( isset($onedef->value) )
-              {
-    			$results[] = $onedef->value;
-			  }
-			break;
-		  }
+	foreach( $defs as $onedef ) {
+	  switch( $onedef->type ) {
+	  case 'textbox':
+	  case 'textarea':
+	  case 'dropdown':
+		if( isset($onedef->value) ) {
+		  $results[] = $onedef->value;
+		}
+		break;
 	  }
-	
+	}
 	return $results;
   }
 
-
   // deprecated
   function GetProductNameFromId( $id )
   {
@@ -578,7 +446,6 @@ EOT;
 	return $product['product_name'];
   }
 
-
   // depreacated
   function is_taxable($product_id)
   {
@@ -586,84 +453,20 @@ EOT;
 	return $tmp['taxable'];
   }
 
-
   function is_shippable($product_id)
   {
 	// todo: add something here.
 	return TRUE;
   }
 
-
-  // deprecated
-  function GetProduct( $id )
-  {
-	return product_ops::get_product($id);
-  }
-
-
-  // deprecated
-  function GetProductAttributes($product_id)
-  {
-	$results = array();
-	$db = $this->GetDb();
-	$query = "SELECT * FROM ".cms_db_prefix()."module_products_attribsets
-               WHERE product_id = ? ORDER BY attrib_set_id";
-	$dbresult = $db->Execute($query,array($product_id));
-	while( $dbresult && ($row = $dbresult->FetchRow()) )
-	  {
-		$results[$row['attrib_set_id']] =  $row['attrib_set_name'];
-	  }
-	return $results;
-  }
-
-
-  // deprecated
-  // ready to remove now?
-  function GetProductAttributeDataComplete($product_id)
-  {
-	$db = $this->GetDb();
-	$data = array();
-
-	$query = 'SELECT * FROM '.cms_db_prefix().'module_products_attribsets
-              WHERE product_id = ? ORDER BY attrib_set_id';
-	$tmp = $db->GetArray($query,array($product_id));
-	
-
-	$tmp2 = cge_array::extract_field($tmp,'attrib_set_id');
-	$q2 = 'SELECT * FROM '.cms_db_prefix().'module_products_attributes
-            WHERE attrib_set_id IN ('.implode(',',$tmp2).') ORDER BY attrib_id ASC';
-	$tmp3 = $db->GetArray($q2);
-
-	for( $i = 0; $i < count($tmp); $i++ )
-	  {
-		$row =& $tmp[$i];
-
-		$attribs = array();
-		for( $j = 0; $j < count($tmp3); $j++ )
-		  {
-			$row2 =& $tmp3[$j];
-			if( $row2['attrib_set_id'] < $row['attrib_set_id'] ) continue;
-			if( $row2['attrib_set_id'] > $row['attrib_set_id'] ) break;
-
-			$attribs[$row2['attrib_text']] = $row2['attrib_adjustment'];
-		  }
-		$data[$row['attrib_set_name']] = $attribs;
-	  }
-
-	if( !count($data) ) return false;
-	return $data;
-  }
-
-
   // deprecated
   static public function GetProductIdsFromCategories($str,$delim = ',')
   {
 	if( empty($str) ) return FALSE;
 	$names = explode($delim,$str);
-	for( $i = 0; $i < count($names); $i++ )
-	  {
-		$names[$i] = trim(trim($names[$i]),"'");
-	  }
+	for( $i = 0; $i < count($names); $i++ ) {
+	  $names[$i] = trim(trim($names[$i]),"'");
+	}
 
 	$db = cmsms()->GetDb();
 
@@ -679,39 +482,31 @@ EOT;
 	return $products;
   }
 
-
   // deprecated 
   static public function GetProductIdsFromHierarchy($hier_str,$delim = ' | ')
   {
 	if( empty($hier_str) ) return FALSE;
 	$hier_str = trim($hier_str);
-	if( $delim != ' | ' )
-	  {
-		$hier_str = str_replace($delim,' | ',$hier_str);
-	  }
+	if( $delim != ' | ' ) {
+	  $hier_str = str_replace($delim,' | ',$hier_str);
+	}
 	
 	$gCms = cmsms();
 	$db = $gCms->GetDb();
 	$hierarchies = array();
-	if( endswith($hier_str,'*') )
-	  {
-		$hier_str = str_replace('*','%',$hier_str);
-		
-		$query = 'SELECT id FROM '.cms_db_prefix().'module_products_hierarchy 
-               WHERE upper(long_name) LIKE upper(?)';
-		$hierarchies = $db->GetCol($query,array($hier_str));
-	  }
-	else
-	  {
-		$query = 'SELECT id FROM '.cms_db_prefix().'module_products_hierarchy
-               WHERE upper(long_name) = upper(?)';
-		$hier_id = $db->GetOne($query,array($hier_str));
-		if( !$hier_id )
-		  {
-			return FALSE;
-		  }
-		$hierarchies[] = $hier_id;
-	  }
+	if( endswith($hier_str,'*') ) {
+	  $hier_str = str_replace('*','%',$hier_str);
+	  $query = 'SELECT id FROM '.cms_db_prefix().'module_products_hierarchy 
+                WHERE upper(long_name) LIKE upper(?)';
+	  $hierarchies = $db->GetCol($query,array($hier_str));
+	}
+	else {
+	  $query = 'SELECT id FROM '.cms_db_prefix().'module_products_hierarchy
+                WHERE upper(long_name) = upper(?)';
+	  $hier_id = $db->GetOne($query,array($hier_str));
+	  if( !$hier_id ) return FALSE;
+	  $hierarchies[] = $hier_id;
+	}
 
 	$tmp = implode(',',$hierarchies);
 	$query = 'SELECT product_id FROM '.cms_db_prefix()."module_products_prodtohier
@@ -720,16 +515,16 @@ EOT;
 	return $products;
   }
 
-
   // deprecated, move to ops
-  function UpdateHierarchyPositions()
+  // internal
+  public function UpdateHierarchyPositions()
   {
 	return product_utils::update_hierarchy_positions();
   }
 
-
   // deprecated, move to ops
-  function BuildHierarchyList()
+  // internal
+  public function BuildHierarchyList()
   {
 	$tmp = hierarchy_ops::get_flat_list(FALSE);
 	$list = array($this->Lang('none')=>-1);
@@ -741,7 +536,6 @@ EOT;
 	return $list;
   }
 
-
   // deprecated, move to ops
   function CreateHierarchyDropdown($id,$name,$selectedvalue)
   {
@@ -750,7 +544,6 @@ EOT;
 	return $this->CreateInputDropdown($id,$name,$tmp,-1,$selectedvalue);
   }
 
-
   // deprecated... use get_pretty_url
   function CreatePrettyLink($id, $action, $returnid='', $contents='', $params=array(), 
 							$warn_message='', $onlyhref=false, $inline=false, $addtext='', 
@@ -833,7 +626,6 @@ EOT;
 	return $out;
   }
 
-
   // creates a form-safe alias string
   function make_alias($string, $isForm=false)
   {
@@ -842,7 +634,6 @@ EOT;
 	return strtolower($string);
   }
 
-
   function HandleUploadedImage($id,$name,$destdir,&$errors,$subfield='',$wmlocation='',$overwrite=false)
   {
 	$this->_load_admin();
@@ -850,42 +641,30 @@ EOT;
 										$wmlocation,$overwrite);
   }
 
-
-  function ProcessImage($srcname,$wmlocation='default')
-  {
-	$this->_load_admin();
-	return products_ProcessImage($this,$srcname,$wmlocation);
-  }
-
-
   // deprecated
   function GetHierarchyInfo($hierarchy_id)
   {
 	return hierarchy_ops::get_hierarchy_info($hierarchy_id);
   }
 
-
   // deprecated
   function GetHierarchyPath($hiearchy_id)
   {
 	return hierarchy_ops::get_hierarchy_path($hierarchy_id);
   }
 
-
   // deprecated
   function GetProductHierarchyPath($productid)
   {
 	return product_ops::get_product_hierarchy_path($productid);
   }
 
-
   function DeleteProduct($productid,$update_search=true)
   {
 	$this->_load_admin();
 	return products_DeleteProduct($this,$productid,$update_search);
   }
 
-
   function _smarty_products_getcategory($params,&$smarty)
   {
 	if( !isset($params['categoryid']) ) return;
@@ -893,11 +672,10 @@ EOT;
 	$catid = (int)$params['categoryid'];
 	$obj = $this->GetCategory($catid);
 	
-	if( isset($params['assign']) )
-	  {
-		$smarty->assign($params['assign'],$obj);
-		return;
-	  }
+	if( isset($params['assign']) ) {
+	  $smarty->assign($params['assign'],$obj);
+	  return;
+	}
 	return $obj;
   }
 
@@ -941,39 +719,13 @@ EOT;
 
   function get_product_info($product_id)
   {
-	$tmp = $this->GetProduct($product_id);
-	if( !is_array($tmp) )
-	  {
-		return FALSE;
-	  }
-	$tmp2 = $this->GetProductAttributes($product_id);
-	if( $tmp2 )
-	  {
-		$db = $this->GetDb();
-		$attr_results = array();
-		$query = 'SELECT * FROM '.cms_db_prefix().'module_products_attributes
-                   WHERE attrib_set_id = ? ORDER BY attrib_id';
-		foreach( $tmp2 as $attr_set_id => $attr_set_name )
-		  {
-			$attr_data = array('name'=>$attr_set_name);
-			$tmp3 = $db->GetArray($query,array($attr_set_id));
-			if( is_array($tmp3) )
-			  {
-				$tmp3 = cge_array::to_hash($tmp3,'attrib_id');
-				$attr_data['values'] = $tmp3;
-			  }
-			$attr_results[$attr_set_id] = $attr_data;
-		  }
-		$tmp['attributes'] = $attr_results;
-	  }
-	$tmp3 = $this->GetFieldDefsForProduct($product_id,true,true);
-	if( is_array($tmp3) )
-	  {
-		$tmp['fields'] = $tmp3;
-	  }
+	$tmp = product_ops::get_product($product_id);
+	if( !is_array($tmp) ) {
+	  return FALSE;
+	}
 	return $tmp;
   }
 } // class
 
 # vim:ts=4 sw=4 noet
-?>
+?>
\ No newline at end of file
