@@ -93,6 +93,11 @@ if( isset($params['sortorder']) )
     $this->SetPreference('sortorder',$params['sortorder']);
   }
 
+if( isset($params['summary_newdefault']) )
+  {
+    $this->SetPreference('summary_newdefault',(int)$params['summary_newdefault']);
+  }
+
 if( isset($params['summary_pagelimit']) )
   {
     $this->SetPreference('summary_pagelimit',(int)$params['summary_pagelimit']);
