@@ -74,6 +74,7 @@ $offset = 0;
 $count = 0;
 $entryarray = '';
 $npages = 0;
+$inline = 0;
 
 
 //
@@ -399,8 +400,8 @@ if( $count )
 	$onerow->details = $row['details'];
 
 	// hierarchy information
-	$onerow->hierarchy_id = product_ops::get_product_hierarchy_id($params['productid']);
-	$onerow->breadcrumb = product_ops::create_hierarchy_breadcrumb($id,$params['productid'],$returnid);
+	$onerow->hierarchy_id = product_ops::get_product_hierarchy_id($row['id']);
+	$onerow->breadcrumb = product_ops::create_hierarchy_breadcrumb($id,$row['id'],$returnid);
 
 	// add custom fields
 	$fielddefs = $this->GetFieldDefsForProduct($row['id'],true,true);
@@ -438,11 +439,10 @@ if( $count )
 	  }
 
 	// add attributes
-	$tmp = $this->GetProductAttributeDataComplete($row['id']);
-	if( is_array($tmp) )
-	  {
-	    $onerow->attributes = $tmp;
-	  }
+	$tmp = products_attrib::load_by_product($row['id']);
+	if( is_array($tmp) ) {
+	  $onerow->attributes = $tmp;
+	}
 
 	$entryarray[] = $onerow;
       }
@@ -461,7 +461,7 @@ $smarty->assign('pagetext',$this->Lang('page'));
 $smarty->assign('oftext',$this->Lang('of'));
 $smarty->assign('pagecount',$npages);
 $smarty->assign('curpage',$pagenum);
-if( $page == 1 )
+if( $pagenum == 1 )
   {
     $smarty->assign('firstlink',$this->Lang('firstpage'));
     $smarty->assign('prevlink',$this->Lang('prevpage'));
@@ -473,12 +473,12 @@ else
     $smarty->assign('firstlink',$this->CreateLink($id,'default',$returnid,
 						  $this->Lang('firstpage'),
 						  $parms));
-    $parms['page'] = $page - 1;
+    $parms['page'] = $pagenum - 1;
     $smarty->assign('prevlink',$this->CreateLink($id,'default',$returnid,
 						  $this->Lang('prevpage'),
 						  $parms));
   }
-if( $page == $npages )
+if( $pagenum == $npages )
   {
     $smarty->assign('lastlink',$this->Lang('lastpage'));
     $smarty->assign('nextlink',$this->Lang('nextpage'));
@@ -490,7 +490,7 @@ else
     $smarty->assign('lastlink',$this->CreateLink($id,'default',$returnid,
 						  $this->Lang('lastpage'),
 						  $parms));
-    $parms['page'] = $page + 1;
+    $parms['page'] = $pagenum + 1;
     $smarty->assign('nextlink',$this->CreateLink($id,'default',$returnid,
 						  $this->Lang('nextpage'),
 						  $parms));
