@@ -594,16 +594,18 @@ if (count($fielddefs) > 0)
 
 $allcategories = $this->GetCategories();
 $catarray = array();
-foreach( $allcategories as $one )
-{
-  $catarray[$one->name] = $one->id;
+if( is_array($allcategories) && count($allcategories) ) {
+  foreach( $allcategories as $one ) {
+    $catarray[$one->name] = $one->id;
+  }
 }
 $selcategories = $this->GetCategoriesForProduct($compid);
 $selcatarray = array();
-foreach( $selcategories as $one )
-{
-  if( !$one->value ) continue;
-  $selcatarray[$one->name] = $one->id;
+if( is_array($selcategories) && count($selcategories) ) {
+  foreach( $selcategories as $one ) {
+    if( !$one->value ) continue;
+    $selcatarray[$one->name] = $one->id;
+  }
 }
 
 #Display template
