@@ -156,76 +156,69 @@ if( !count($parents) ) {
  }
 
 $data = array();
-if( count($nodes) )
-  {
-    // this will only display the selected hierarchies (not including their children) that have products.
-    $nodes = implode(',',$nodes);
-    $query = 'SELECT ph.*,count(pr.id) AS count FROM '.cms_db_prefix().'module_products_hierarchy ph
-                LEFT OUTER JOIN '.cms_db_prefix().'module_products_prodtohier pth
-                  ON ph.id = pth.hierarchy_id
-                LEFT OUTER JOIN '.cms_db_prefix().'module_products pr
-                  ON pth.product_id = pr.id
-               WHERE pr.status = \'published\'
-                 AND ph.id IN ('.$nodes.')
-               GROUP BY ph.id ORDER BY ph.hierarchy';
-    $tmp = $db->GetArray($query);
-    products_byhierarchy_postprocess($tmp,$params,$summarypage,$hierpage);
-    $data = $tmp;
-  }
-else
-  {
-    foreach( $parents as $one )
-      {
-	$parent_id = '';
-	if( is_array($one) ) {
-	  $parent_id = $one['id'];
-	}
-	else if( is_int($one) ) {
-	  $parent_id = $one;
-	}
+if( count($nodes) ) {
+  // this will only display the selected hierarchies (not including their children) that have products.
+  $nodes = implode(',',$nodes);
+  $query = 'SELECT ph.*,count(pr.id) AS count FROM '.cms_db_prefix().'module_products_hierarchy ph
+              LEFT OUTER JOIN '.cms_db_prefix().'module_products_prodtohier pth
+                ON ph.id = pth.hierarchy_id
+              LEFT OUTER JOIN '.cms_db_prefix().'module_products pr
+                ON pth.product_id = pr.id
+             WHERE pr.status = \'published\'
+               AND ph.id IN ('.$nodes.')
+             GROUP BY ph.id ORDER BY ph.hierarchy';
+  $tmp = $db->GetArray($query);
+  products_byhierarchy_postprocess($tmp,$params,$summarypage,$hierpage);
+  $data = $tmp;
+}
+else {
+  foreach( $parents as $one ) {
+    $parent_id = '';
+    if( is_array($one) ) {
+      $parent_id = $one['id'];
+    }
+    else if( is_int($one) ) {
+      $parent_id = $one;
+    }
 
-	if( $parent_id == '' ) continue;
+    if( $parent_id == '' ) continue;
 
-	$tmp = product_utils::hierarchy_get_tree($parent_id);
-	if( is_array($tmp) && count($tmp) )
-	  {
-	    products_byhierarchy_postprocess($tmp,$params,$summarypage,$hierpage);
-	    if( is_array($one) ) {
-	      $one['children'] = $tmp;
-	      $data[] = $one;
-	    }
-	    else {
-	      $data[] = $tmp;
-	    }
-	  }
+    $tmp = product_utils::hierarchy_get_tree($parent_id);
+    if( is_array($tmp) && count($tmp) ) {
+      products_byhierarchy_postprocess($tmp,$params,$summarypage,$hierpage);
+      if( is_array($one) ) {
+	$one['children'] = $tmp;
+	$data[] = $one;
       }
+      else {
+	$data[] = $tmp;
+      }
+    }
   }
+}
 
 $hierdata = '';
-if( count($data) == 1 && empty($nodes) )
-  {
-    $data = $data[0];
-  }
+//debug_display($data);
+// if( count($data) == 1 && empty($nodes) ) {
+//   $data = $data[0];
+// }
 $smarty->assign('hierdata',$data);
-if( count($parents) == 1 )
-  {
-    $hierdata = hierarchy_ops::get_hierarchy_info($parents[0]);
-    if( $hierdata )
-      {
-	$hierdata['canonical'] = $this->CreatePrettyLink($id,'hierarchy',$returnid,'',array('parent'=>$parents[0]),'',true);
-	$smarty->assign('hierarchy_item',$hierdata);
-      }
+if( count($parents) == 1 ) {
+  $hierdata = hierarchy_ops::get_hierarchy_info($parents[0]['id']);
+  if( $hierdata ) {
+    $hierdata['canonical'] = $this->CreatePrettyLink($id,'hierarchy',$returnid,'',array('parent'=>$parents[0]['id']),'',true);
+    $smarty->assign('hierarchy_item',$hierdata);
   }
+}
 $smarty->assign('hierarchy_image_location',$config['uploads_url'].'/'.$this->GetName().'/hierarchy');
 
 //
 // template
 //
 $thetemplate = 'byhierarchy_'.$this->GetPreference(PRODUCTS_PREF_DFLTBYHIERARCHY_TEMPLATE);
-if( isset($params['hierarchytemplate'] ) )
-  {
-    $thetemplate = 'byhierarchy_'.$params['hierarchytemplate'];
-  }
+if( isset($params['hierarchytemplate'] ) ) {
+  $thetemplate = 'byhierarchy_'.$params['hierarchytemplate'];
+}
 echo $this->ProcessTemplateFromDatabase($thetemplate);
 #
 # EOF
