@@ -30,6 +30,7 @@ $lang['areyousure'] = 'Are You Sure?';
 $lang['areyousure_deleteproduct'] = 'Are you sure you really want to delete this item, and all of the accompanying information for it?';
 $lang['ascending'] = 'Ascending';
 $lang['attribute_name'] = 'Attribute Name';
+$lang['attrib_text'] = 'Text';
 $lang['automatic'] = 'Automatic';
 
 # B
@@ -46,13 +47,15 @@ $lang['categorylisttemplates'] = 'CategoryList Templates';
 $lang['categorylisttemplate_addedit'] = 'Add/Edit A CategoryList Template';
 $lang['centimeters'] = 'Centimeters';
 $lang['checkbox'] = 'Checkbox';
-$lang['confirm_copyattributes'] = 'Any existing attribute sets for this item will be removed. Are you sure you want to continue?';
+$lang['confirm_copyoptions'] = 'Any existing options for this item will be replaced. Are you sure you want to continue?';
 $lang['confirm_delete_hierarchy_node'] = 'Are you sure you want to delete this node?  Any items that are using this node will be set to no hierarchy';
+$lang['confirm_deletealloptions'] = 'Are you sure you want to delete all options for this product?';
 $lang['confirm_import'] = "Are you sure you really want to do this?\\n\\nImproper settings, or an invalid config file could completely corrupt a currently valid and working system.";
 $lang['copy'] = 'Copy';
 $lang['copy_product'] = 'Copy this item';
 $lang['copy_attrib_sets'] = 'Copy Attribute Sets';
 $lang['copy_category']  = 'Copy Category';
+$lang['copy_options_from'] = 'Copy all options from';
 $lang['createddate'] = 'Created Date';
 $lang['current_value'] = 'Current Value';
 
@@ -64,6 +67,7 @@ $lang['default_template_notice'] = <<<EOT
 <strong>Note:</strong> The contents of these text areas are used to determine the default content of templates when you click &quot;Add Template&quot; in the appropriate template tab.  Editing one of these text areas will have no immediate effect on your website.
 EOT;
 $lang['delete'] = 'Delete';
+$lang['delete_all'] = 'Delete All';
 $lang['delete_attribset'] = 'Delete Attribute';
 $lang['delete_hierarchy_item'] = 'Delete Hierarchy Item';
 $lang['descending'] = 'Descending';
@@ -87,20 +91,25 @@ $lang['edit_attribsets_for'] = 'Edit Attribute Sets For';
 $lang['edit_attributes'] = 'Edit Attributes';
 $lang['edit_category'] = 'Edit Category';
 $lang['edit_category_fields'] = 'Edit Category Fields for &quot;%s&quot;';
-$lang['edit_hierarchy_item'] = 'Edit Hierarchy Item';
+$lang['edit_hierarochy_item'] = 'Edit Hierarchy Item';
+$lang['edit_option_notes'] = 'Edit Option Notes';
+$lang['edit_options'] = 'Edit Product Options';
+$lang['edit_product'] = 'Edit Item ';
 $lang['errors'] = 'Errors';
 $lang['error_attribset_exists'] = 'An attribute with that name already exists';
 $lang['error_dberror'] = 'Database error';
 $lang['error_duplicate_sku'] = 'Duplicate SKU value found';
-$lang['error_fieldvalue_empty'] = 'The Field Value cannot be empty';
+$lang['error_fieldvalue_empty'] = 'The field value cannot be empty';
 $lang['error_fileformat'] = 'File Format Problem';
 $lang['error_filenotfound'] = 'File Not Found';
 $lang['error_fileopen'] = 'Problem opening file %s';
+$lang['error_invalidparamcount'] = 'Invalid (or not matching) parameter count';
 $lang['error_invalidparent'] = 'Invalid Parent (a hierarchy node cannot be it\'s own parent)';
 $lang['error_invalid_name'] = 'The custom field value entered is invalid (contains non alphanumeric characters)';
 $lang['error_invalid_value'] = 'Invalid value specified';
 $lang['error_missingparam'] = 'A required parameter is missing or invalid';
 $lang['error_nameused'] = 'An item by that name is already in use';
+$lang['error_needtworows'] = 'A minimum of two rows is requried';
 $lang['error_nofieldtype'] = 'Please select a field type';
 $lang['error_noname'] = 'You must supply a name';
 $lang['error_onequantityfield'] = 'Only one quantity field is allowed';
@@ -110,8 +119,12 @@ $lang['error_product_aliasused'] = 'The alias specified is already in use';
 $lang['error_product_nameused'] = 'An item by that name already exists';
 $lang['error_product_notfound'] = 'The requested item could not be found';
 $lang['error_product_skuused'] = 'That SKU value is already in use by another item';
+$lang['error_product_skuused_atrow'] = 'That SKU value at row %d is already in use by another item';
 $lang['error_price_adjustment'] = 'Invalid price adjustment value for item %s';
+$lang['erorr_qoh_negative_atrow'] = 'Quantity on hand cannot be negative at row %d';
 $lang['error_sku_required'] = 'Please enter a unique SKU';
+$lang['error_sku_required_atrow'] = 'Please enter a unique SKU on row %d';
+$lang['error_text_empty_atrow'] = 'The text field at row %d cannot be empty';
 $lang['error_upload_failed'] = 'Upload failed: %s';
 $lang['exclude_categories'] = 'Exclude items in the selected categories from the results';
 $lang['expire_six_months'] = 'After Six Months';
@@ -200,7 +213,10 @@ $lang['modifieddate'] = 'Modified Date';
 $lang['module_description'] = 'A module for managing a catalog of items, their price, images, etc, and for allowing users to build a cart';
 $lang['move_down'] = 'Move Down';
 $lang['move_up'] = 'Move Up';
-$lang['msg_eventhandlers_created'] = 'Event Handlers Created';
+$lang['msg_eventhandlers_created'] = 'Event handlers created';
+$lang['msg_optionscopied'] = 'Product options copied (but not saved yet)';
+$lang['msg_options_deleted'] = 'Product options deleted for product %d';
+$lang['msg_options_saved'] = 'Product options saved';
 $lang['msg_productcopied'] = 'Item successfully copied.  You are now editing the copy.  Any sku information in the item, and/or attributes has been cleared';
 
 # N
@@ -212,10 +228,12 @@ $lang['no'] = 'No';
 $lang['nonamegiven'] = 'No name was supplied';
 $lang['nonamegiven'] = 'No name was supplied';
 $lang['none'] = 'None';
+$lang['notes'] = 'Notes';
 $lang['nothing_selectd'] = 'Nothing selected';
 
 # O
 $lang['of'] = 'Of';
+$lang['ok'] = 'Ok';
 $lang['operation_cancelled'] = 'Operation Cancelled';
 $lang['operation_complete'] = 'Operation Complete';
 
@@ -251,7 +269,7 @@ $lang['param_fieldval'] = 'Used in the <em>default</em> and <em>ajax_propval</em
 $lang['param_hierarchy'] = 'Useed in the <em>default</em> and hierachy actions this parameter has two uses.  When used in the default (summary) action, this parameter specifies that only items in that location of the hierarchy should be displayed.  Wildcard character can be used so that you can specify parent/child relationships as well.  i.e {Products hierarchy=\'trucks*\'} will create a summary report of all trucks, including the children in the hierarchy.  Similarly, {Products hierarchy=\'*trucks\'} will display a summary report of all trucks, and all items beloging to any parent in the hierarchy.  A comma separated list of expressions can be supplied.  i.e: {Products action=hierarchy hierarchy=\'trucks,cars\'}';
 $lang['param_hierarchytemplate'] = 'This parameter specifies the template that should be used for the hierarchy display. If no value is specified, then the current default template of that type is used.';
 $lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline';
-$lang['param_notpretty'] = 'Thie parameter specifies a comma separated list of actions to which pretty urls should not be generated.  i.e: notpretty=hierarchy,default will not generate pretty urls to hierarchy, or summary (default) actions, but will allow generation of pretty urls to detail views.  As a special vaue &quot;all&quot; can be used to specify that no pretty urls should be generated';
+$lang['param_notpretty'] = 'This parameter specifies a comma separated list of actions to which pretty urls should not be generated.  i.e: notpretty=hierarchy,default will not generate pretty urls to hierarchy, or summary (default) actions, but will allow generation of pretty urls to detail views.  As a special value &quot;all&quot; can be used to specify that no pretty urls should be generated';
 $lang['param_pagelimit'] = 'Useful only with the <em>default</em> or search actions, this parameter specifies how many items should be listed on each page.';
 $lang['param_parent'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies the hierarchy id of the starting location of the report.';
 $lang['param_parents'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies a comma separated list of hierarchy names that specify to create numerous heirarchy trees from the specified location(s).  Hierarchy names must be unique, and not contain any special chars.';
@@ -432,6 +450,7 @@ $lang['view'] = 'View';
 $lang['viewable_fields'] = 'Select custom fields to view in the table';
 
 # W
+$lang['warn_edit_product_options'] = 'Each product option must have a unique string.  If SKU is required then it must be unique across the entire system.';
 $lang['watermark_location'] = 'Watermark Location';
 $lang['weight'] = 'Weight';
 $lang['with_selected'] = 'With Selected';
