@@ -110,74 +110,6 @@ $lang['filters'] = 'Filter';
 $lang['firstpage'] = '<<';
 $lang['general_settings'] = 'Allgemeine Einstellungen';
 $lang['go'] = 'Los';
-$lang['help'] = '<h3>Was macht dieses Modul?</h3>
-<p>Dieses Modul bietet die M&ouml;glichkeit, Informationen &uuml;ber Produkte und deren Kategorien zu sammeln, organisieren und anzuzeigen. Dieses Modul kann allein eingesetzt werden oder als Teil einer E-Commerce L&ouml;sung. Das Modul unterst&uuml;tzt Produkte in mehreren Kategorien, Angaben zu Preis, Gewicht, etc. und individuelle Felder f&uuml;r jedes Produkt. Individuellen Produkt-Felder k&ouml;nnen eigene Preise zugeordnet werden. Die Umsatzsteuer kann global oder f&uuml;r jedes Produkt individuell aktiviert werden.</p>
-<p>Dieses Modul unterst&uuml;tzt mehrere Bilder je Produkt, individuelle Felder verschiedener Typen und auch interne (nicht &ouml;ffentliche) Felder.</p>
-<h3>Funktionen:</h3>
-<ul>
-  <li>Verschiedene Ansichten</li>
-    <ul>
-      <li>Produkt-Listenansicht</li>
-      <li>Kategorie-Listenansicht</li>
-      <li>Detail Ansicht</li> 
-      <li>Verzweigte Hierarchie Ansichten</li>
-    </ul>
-  <li>Komplett Datenbank-basierende Templates</li>
-  <p>Es k&ouml;nnen mehrere Templates f&uuml;r jede Ansicht gespeichert, f&uuml;r jede Ansicht ein Standard-Template festgelegt und das gew&uuml;nschte Template f&uuml;r eine Ansicht kann als Parameter im Platzhalter angegeben werden.</p>
-  <li>Sortierung und Bl&auml;tter-Funktion in der Listenansicht</li>
-  <li>Artikel k&ouml;nnen mehreren Kategorien zugeordnet werden</li>
-  <li>Mehrere individuelle Felder k&ouml;nnen definiert werden, dabei gibt es verschiedene Typen, inklusive Bilder</li>
-  <li>Automatische Thumbnail-Erzeugung</li>
-  <li>Interne Felder</li>
-  <li>Individuelle Produkt-Eigenschaften (mit eigenen Preisen)</li>
-  <li>Felder f&uuml;r Gewicht, Umsatzsteuer und anderes (f&uuml;r die Verwendung in E-Commerce L&ouml;sungen)</li>
-  <li>Artikel k&ouml;nnen den Status &quot;Ver&ouml;ffentlicht&quot; oder &quot;Entwurf&quot; haben.</li>
-  <li>Unterst&uuml;tzung von Pretty URLs</li>
-  <li><strong>Vieles mehr...</strong></li>
-</ul>
-
-<h3>Wie kann dieses Modul verwendet werden:</h3>
-<ul>
-<li>Einstellungen</li>
-<p>Dies ist normalerweise nur eine Formalit&auml;t. Hier werden das Preis-Symbol und -W&auml;hrung, die anzuzeigenden Felder u.v.m. eingestellt.</p>
-<li>Setup f&uuml;r Benutzer und Berechtigungen</li>
-<p>Dieses Modul nutzt die &#039;Modify Templates&#039; Berechtigung, um Nutzern das Bearbeiten der Templates zu erm&ouml;glichen. Ebenso wird die &#039;Modify Site Preferences&#039; Berechtigung verwendet f&uuml;r den Einstellungs-Reiter. Um Feld Definitionen, Artikel, Kategorien oder Hierarchien zu bearbeiten, ben&ouml;tigt der Benutzer die Berechtigung &#039;Modify Products&#039;.</p>
-<li>(optional) Erstellen von ein oder mehreren Kategorien</li>
-<p>Dieser Schritt ist optional, aber es ist sicher ratsam, dies so fr&uuml;h wie m&ouml;glich zu tun, um sp&auml;teren Mehraufwand zu vermeiden. Um eine Kategorie hinzuzuf&uuml;gen, klicken Sie auf den Reiter &quot;Kategorien&quot; und dort auf den Link &quot;Kategorie hinzuf&uuml;gen&quot;, wo schlie&szlig;lich der Name der Kategorie angegeben werden kann.</p>
-<li>(optional) Erstellen von ein oder mehreren individuellen Feldern</li>
-<p>Dieser Schritt ist optional. Individuelle Felder werden nocht ben&ouml;tigt, wenn dieses Modul das gew&uuml;nschte bietet. Wenn Sie jedoch zus&auml;tzliche Informationen zum Artikel ben&ouml;tigen, k&ouml;nnen Sie hier individuelle Felder erstellen. Ein individuelles Feld zu erstellen ist &auml;hnlich wie eine Kategorie zu erstellen, abgesehen davon, dass mehr Daten angegeben werden m&uuml;ssen.</p>
-<p>Derzeit sind sechs Typen von individuellen Feldern verf&uuml;gbar: &#039;textbox&#039;, &#039;checkbox&#039;, &#039;textarea&#039;, &#039;dropdown&#039; und &#039;file&#039;. W&auml;hlen Sie einen Typ aus, geben Sie dem Feld einen Namen und legen Sie fest, ob das Feld &ouml;ffentlich sein soll oder intern. Best&auml;tigen Sie schlie&szlig;lich mit &quot;Absenden&quot;.</p>
-<li>Erstellen von ein oder mehreren Artikeln</li>
-<p>Sie sollten ein oder mehrere Artikel erstellen, die auf der Webseite angezeigt werden sollen. Geben Sie jedem Artikel einen Namen, einen Preis und weitere Informationen.</p>
-<p>Wenn Kategorien erstellt wurden, wird f&uuml;r jede Kategorie eine Checkbox angezeigt. W&auml;hlen Sie, unter welchen Kategorien der Artikel angezeigt werden soll.</p>
-<p>Wenn individuelle Felder erstellt wurden, werden diese auch abgefragt. Geben Sie auch hier die vorhandenen Daten ein. Dies ist optional.</p>
-<li>Einf&uuml;gen der entsprechenden Tags in das Seiten Template oder den Seiten Inhalt</li>
-<p>Die einfachste Variante ist es, den <strong>{Products}</strong> Tag in den Inhalts-Textbereich oder in einem Template einzuf&uuml;gen.</p>
-<p>Wenn Sie das Verhalten dieses Moduls nach Ihren W&uuml;nschen anpassen wollen, k&ouml;nnen Sie verschiedene Parameter zum <strong>{Products}</strong> Tag hinzuf&uuml;gen. Die komplette Liste der Parameter finden Sie weiter unten im Text. Wenn Sie zum Beispiel eine Liste von Produkten einer Kategorie anzeigen wollen, k&ouml;nnen Sie den Tag wie folgt verwenden: <code>{Products category=&#039;categoryname&#039;}</code></p>
-</ul>
-<h3>Smarty Plugins</h3>
-<p>Dieses Modul erweitert Smarty um ein oder mehrere Plugins, die das Einf&uuml;gen von Artikeldaten in die Templates vereinfachen:</p>
-<ul>
-  <li><code>{products_getcategory categoryid=&#039;99&#039; [assign=&#039;tmp&#039;]}</code>
-  <p>Das Plugin liefert die kompletten Daten zu einer Kategorie-ID und weisst diese der ggf. angegebenen Smarty Variablen zu.  Der R&uuml;ckgabewert ist ein Objekt mit allen Daten einer Kategorie, inklusive der Feldwerte.<br/>Bsp.: <code>{products_getcategory categoryid=1 assign=&#039;tmp&#039;}Category name = {$tmp->name}</code></p>
-  </li>
-</ul>
-
-<h3>Support</h3>
-<p>Dieses Modul beinhaltet keinen kommerziellen Support. Es existieren jedoch eine Reihe von Ressourcen, die Ihnen bei diesem Modul helfen k&ouml;nnen:</p>
-<ul>
-<li>F&uuml;r die neueste Version dieses Moduls, f&uuml;r FAQs oder Fehlerberichte, besuchen Sie die Entwickler-Webseite von CMS made simple: <a href="http://dev.cmsmadesimple.org">Developers Forge</a> und suchen Sie nach &#039;Products&#039;.</li>
-<li>Um kommerziellen Support zu erhalten, senden Sie eine EMail zum Author <a href="mailto:calguy1000@cmsmadesimple.org">Robert Campbell</a>.</li>
-<li>Zus&auml;tzliche Diskussionen &uuml;ber dieses Modul finden Sie im CMS made simple Forum: <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forum</a>.</li>
-<li>F&uuml;r Fragen oder beschr&auml;nkten technischen Support kann der Author via IRC erreicht werden: <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
-</ul>
-<h3>Urheberrecht und Lizenz:</h3>
-<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. Alle Rechte vorbehalten.</p>
-<p>Dieses Programm ist freie Software. Sie k&ouml;nnen es unter den Bedingungen der GNU General Public License, wie von der Free Software Foundation ver&ouml;ffentlicht, weitergeben und/oder modifizieren, entweder gem&auml;&szlig; Version 2 der Lizenz oder (nach Ihrer Option) jeder sp&auml;teren Version.</p>
-<p>Doch da diese Software ein Zusatzmodul zu CMS Made Simple ist gilt eine besondere Ausnahme zur GPL. 
-Sie d&uuml;rfen diese Software in keiner Version von CMS Made Simple einsetzen die nicht unter der GPL lizensiert ist, oder im Administrationsbereich nicht klar und deutlich darauf hinweist, das die Site mit CMS Made Simple erstellt wurde.</p>
-<p>Die Ver&ouml;ffentlichung dieses Programms erfolgt in der Hoffnung, da&szlig; es Ihnen von Nutzen sein wird, aber OHNE IRGENDEINE GARANTIE, sogar ohne die implizite Garantie der MARKTREIFE oder der VERWENDBARKEIT F&Uuml;R EINEN BESTIMMTEN ZWECK. Details finden Sie in der GNU General Public License.</p>
-<p>Sie sollten ein Exemplar der GNU General Public License zusammen mit diesem Programm erhalten haben. Falls nicht, schreiben Sie an die Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA oder lesen Sie sie <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
 $lang['hierarchy'] = 'Hierarchie';
 $lang['hierarchy_position'] = 'Hierarchie-Position';
 $lang['hierarchy_settings'] = 'Hierarchie-Einstellungen';
@@ -411,4 +343,4 @@ $lang['qca'] = 'P0-1362779760-1309265682636';
 $lang['utma'] = '156861353.1681295217.1311961821.1312317698.1312377783.16';
 $lang['utmz'] = '156861353.1311961821.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmc'] = '156861353';
-?>
\ No newline at end of file
+?>
