@@ -29,6 +29,7 @@ $lang['areyousure'] = 'Er du sikker?';
 $lang['areyousure_deleteproduct'] = 'Er du virkelig sikker p&aring; at du vil slette dette produktet og all dets tilh&oslash;rende informasjon?';
 $lang['ascending'] = 'Stigende';
 $lang['attribute_name'] = 'Attributt navn';
+$lang['attrib_text'] = 'Tekst';
 $lang['automatic'] = 'Automatisk';
 $lang['btn_setecomhandlers'] = 'Sett Ecommerce hendelses behandlere';
 $lang['byhierarchytemplates'] = 'Hierarki rappormaler';
@@ -41,13 +42,15 @@ $lang['categorylisttemplates'] = 'Kategoriliste maler';
 $lang['categorylisttemplate_addedit'] = 'Legg til/rediger kategori Listemal';
 $lang['centimeters'] = 'Centimeter';
 $lang['checkbox'] = 'Avkrysningsboks';
-$lang['confirm_copyattributes'] = 'Eventuelle eksisterende attributtsett for dette produktet vil bli fjernet. Er du sikker p&aring; at du vil fortsette?';
+$lang['confirm_copyoptions'] = 'Alle eksisterende valg for dette produktet vil bli erstattet. Er du sikker p&aring; at du vil fortsette?';
 $lang['confirm_delete_hierarchy_node'] = 'Er du sikker p&aring; at du vil slette denne noden? Alle produkter som bruker denne noden vil bli satt til ingen hierarki';
+$lang['confirm_deletealloptions'] = 'Er du sikker p&aring; at du vil slette alle valg for dette produktet?';
 $lang['confirm_import'] = 'Er du helt sikker p&aring; at du vil gj&oslash;re dette?\n\nFeil innstillinger eller en ugyldig konfigurasjonsfil kan fullstendig &oslash;delegge et n&aring; gyldig og fungerende system.';
 $lang['copy'] = 'Kopier';
 $lang['copy_product'] = 'Kopier dette produktet';
 $lang['copy_attrib_sets'] = 'Kopier attributtsettene';
 $lang['copy_category'] = 'Kopier kategori';
+$lang['copy_options_from'] = 'Kopier alle valg fra';
 $lang['createddate'] = 'Opprettet dato';
 $lang['current_value'] = 'N&aring;v&aelig;rende verdi';
 $lang['data'] = 'Data ';
@@ -55,6 +58,7 @@ $lang['default'] = 'Standard';
 $lang['defaulttemplates'] = 'Standard maler';
 $lang['default_template_notice'] = '<strong>Merk:</strong> Innholdet i disse teksomr&aring;dene benyttes for &aring; lage standardinnhold i malene n&aring;r du klikker &#039;Legg til mal&#039; i den aktuelle malfanen. &Aring; redigere en av disse tekstomr&aring;dene vil ikke ha umiddelbar effekt p&aring; ditt nettsted.';
 $lang['delete'] = 'Slett';
+$lang['delete_all'] = 'Slett alle';
 $lang['delete_attribset'] = 'Slett attributt';
 $lang['delete_hierarchy_item'] = 'Slett hierarki artikkel';
 $lang['descending'] = 'Synkende';
@@ -76,7 +80,10 @@ $lang['edit_attribsets_for'] = 'Rediger attributt sett for';
 $lang['edit_attributes'] = 'Rediger attributter';
 $lang['edit_category'] = 'Rediger Kategori';
 $lang['edit_category_fields'] = 'Rediger Kategori felter';
-$lang['edit_hierarchy_item'] = 'Rediger hierarki artikkel';
+$lang['edit_hierarochy_item'] = 'Rediger hierarki artikkel';
+$lang['edit_option_notes'] = 'Rediger valg noter';
+$lang['edit_options'] = 'Rediger produkt valg';
+$lang['edit_product'] = 'Rediger produkt';
 $lang['errors'] = 'Feil';
 $lang['error_attribset_exists'] = 'En attributt med det navnet eksisterer allerede';
 $lang['error_dberror'] = 'Databasefeil';
@@ -85,11 +92,13 @@ $lang['error_fieldvalue_empty'] = 'Feltverdien kan ikke v&aelig;re tom';
 $lang['error_fileformat'] = 'Filformat rpoblem';
 $lang['error_filenotfound'] = 'Fil ikke funnet';
 $lang['error_fileopen'] = 'Problem med &aring; &aring;pne filen %s';
+$lang['error_invalidparamcount'] = 'Ugyldig (eller ikke samsvarende) parameter teller';
 $lang['error_invalidparent'] = 'Ugyldig foreldre (en hierarki node kan ikke v&aelig;re sin egen foreldre)';
 $lang['error_invalid_name'] = 'Ekstra(custom) feltverdien som ble oppgitt er ugyldig (inneholder ikke-alfanummeriske tegn)';
 $lang['error_invalid_value'] = 'Ugyldig verdi oppgitt';
 $lang['error_missingparam'] = 'En n&oslash;dvendig parameter mangler eller er ugyldig';
 $lang['error_nameused'] = 'En artikkel med det navnet eksisterer allerede';
+$lang['error_needtworows'] = 'Et minimum av to rader er p&aring;krevd';
 $lang['error_nofieldtype'] = 'Vennligst velg en felttype';
 $lang['error_noname'] = 'Du m&aring; oppgi et navn';
 $lang['error_onequantityfield'] = 'Kun et mengde-felt tillatt';
@@ -99,8 +108,12 @@ $lang['error_product_aliasused'] = 'Alias som ble oppgitt er allerede i bruk';
 $lang['error_product_nameused'] = 'Et produkt med det navnet eksisterer allerede';
 $lang['error_product_notfound'] = 'Produktet ble ikke funnet';
 $lang['error_product_skuused'] = 'Dette V.nr.(SKU) er allerede i bruk av et annet produkt';
+$lang['error_product_skuused_atrow'] = 'Denne SKU/varenummer verdi p&aring; rad %d er allerede i bruk av et annet produkt';
 $lang['error_price_adjustment'] = 'Ugyldig prisjusteringsverdi for enhet %s';
+$lang['erorr_qoh_negative_atrow'] = 'Antall p&aring; h&aring;nden kan ikke v&aelig;re negativ p&aring; rad %d';
 $lang['error_sku_required'] = 'Vennligst oppgit et unikt V.nr.(SKU) ';
+$lang['error_sku_required_atrow'] = 'Vennligst oppgi en unik SKU/varenummer p&aring; rad %d';
+$lang['error_text_empty_atrow'] = 'Tekstfeltet p&aring; rad %d kan ikke v&aelig;re tomt';
 $lang['error_upload_failed'] = 'Opplasting feilet: %s';
 $lang['exclude_categories'] = 'Ekskluder produkter i de valgte kategoriene fra resultatene';
 $lang['expire_six_months'] = 'Etter seks m&aring;neder';
@@ -152,7 +165,7 @@ $lang['info_delimiter'] = 'Spesifiser bokstaven (eller bokstavene) som separerer
 $lang['info_duplicateproducts'] = 'Spesifiser hvordan systemet skal behandle et produkt som har et navn som allerede eksisterer i CSV filen';
 $lang['info_fielddefs_tab'] = '<strong>Merk: </strong> Alle felter definert her er tilgjengjelige for alle produkter.';
 $lang['info_fieldproblems'] = 'Problemer ble oppdaget under h&aring;ndtering av et eller flere ekstra(custom) felter. Handlingen er vellykket fullf&oslash;rt, men du b&oslash;r unders&oslash;ke og korrigere disse problemene';
-$lang['info_handleimages'] = 'Ved import, om et bilde filnavn blir funnet i en feltkolonne, skal det bli fjernet fra kilde lokasjonen, vannmerket, miniatyrbildet, og felttypen endres til &quot;image&quot;';
+$lang['info_handleimages'] = 'Ved import, om et bilde filnavn blir funnet i en feltkolonne, skal det bli flyttet fra kilde lokasjonen, vannmerket, miniatyrbildet, og felttypen endres til &quot;image&quot;';
 $lang['info_hierpage'] = 'Bruk denne siden for hierarkivisninger. Dene sideID vil ikke bli spesifisert p&aring; webadressen.';
 $lang['info_imagepath'] = 'Stien (relativt til uploads katalogen) hvor bilder referert til i importfilen, kan bli funnet';
 $lang['info_imagestuff_deprecated'] = 'Bildebehandlingsfunksjoner er foreldet og vil bli fjernet i en fremtidig versjon. Bruk CGSmartImage for inline bildebehandling.';
@@ -176,6 +189,9 @@ $lang['module_description'] = 'En modul for &aring; behandle en katalog med prod
 $lang['move_down'] = 'Flytt ned';
 $lang['move_up'] = 'Flytt opp';
 $lang['msg_eventhandlers_created'] = 'Hendelsesbehandlere opprettet';
+$lang['msg_optionscopied'] = 'Produkt valg kopiert (men ikke lagret enn&aring;)';
+$lang['msg_options_deleted'] = 'Produkt valg slettet for produkt %d';
+$lang['msg_options_saved'] = 'Produkt valg lagret';
 $lang['msg_productcopied'] = 'Produktet ble kopiert. Du redigerer n&aring; kopien. Enhver sku/varenummer informasjon i produktet, og/eller attributter er fjernet';
 $lang['name'] = 'Navn';
 $lang['needpermission'] = 'Du har ikke den n&oslash;dvendige rettigheten: %s';
@@ -184,8 +200,10 @@ $lang['nextpage'] = ' >';
 $lang['no'] = 'Nei';
 $lang['nonamegiven'] = 'Ingen navn oppgitt';
 $lang['none'] = 'Ingen';
+$lang['notes'] = 'Merknader';
 $lang['nothing_selectd'] = 'Ingenting valgt';
 $lang['of'] = 'av';
+$lang['ok'] = 'OK';
 $lang['operation_cancelled'] = 'Operasjon avbrutt';
 $lang['operation_complete'] = 'Operasjon ferdig';
 $lang['page'] = 'Side';
@@ -212,17 +230,15 @@ $lang['param_categorylistdtltemplate'] = 'Kan kun benyttes med categorylist hand
 $lang['param_detailpage'] = 'Dette spesifiserer sideid&#039;en eller sidealias som skal benyttes for &aring; vise detaljrapporten. Dette kan benyttes med <em>default</em> eller s&oslash;k handlingene.';
 $lang['param_detailtemplate'] = 'Denne parameter spesifiserer malen som skal benyttes for detaljmodus visning. Om ingen verdi er oppgitt vil n&aring;v&aelig;rende standard mal av denne type bli benyttet. Denne parameter har ingen virkning n&aring;r vakre urler er p&aring;sl&aring;tt.';
 $lang['param_excludecat'] = 'Gjelder kun til standard (sammendrag) visning, hvor denne parameteren vil tillate unntak av produkter som er i en bestemt kategori fra resultatet. En kommaseparert liste med kategorinavn er tillatt. Denne parameteren kan fungere sammen med kategori-parameteren for &aring; gi en liste over produkter som er i denne kategorien, men ikke i den kategorien';
-$lang['param_field'] = '
-Used in the <em>fieldlist</em> and the <em>ajax_propval</em> actions. In the fieldlist action, this parameter is required to specify the name of a user defined property to create a list from.  In the ajax_propval action this parameter is used to specify which field to use to extract a list of values.  Any valid field names are accepted (though only text field and dropdown field names will work properly.  Additionally the special values ::name::, ::sku::, and ::alias:: can be specified to return values from the product name, sku and alias respectively.';
-$lang['param_fieldval'] = '
-Used in the <em>default</em> and <em>ajax_propval</em> actions, this parameter allows specifying a field value to limit results by.  In the default value these special values are accepted: &amp;quot;::null::&amp;quot; &amp;quot;::notnull::&amp;quot;. In the ajax_propval action this field is expected to contain only a few letters, to indicate a small filter.  i.e: fieldval=b to return all field values that begin with the letter b.';
+$lang['param_field'] = 'Used in the <em>fieldlist</em> and the <em>ajax_propval</em> actions. In the fieldlist action, this parameter is required to specify the name of a user defined property to create a list from.  In the ajax_propval action this parameter is used to specify which field to use to extract a list of values.  Any valid field names are accepted (though only text field and dropdown field names will work properly.  Additionally the special values ::name::, ::sku::, and ::alias:: can be specified to return values from the product name, sku and alias respectively.';
+$lang['param_fieldval'] = 'Used in the <em>default</em> and <em>ajax_propval</em> actions, this parameter allows specifying a field value to limit results by.  In the default value these special values are accepted: &amp;quot;::null::&amp;quot; &amp;quot;::notnull::&amp;quot;. In the ajax_propval action this field is expected to contain only a few letters, to indicate a small filter.  i.e: fieldval=b to return all field values that begin with the letter b.';
 $lang['param_hierarchy'] = 'Kan kun benyttes i <em>default</em> og hierarki handlinger. Denne parameter har to oppgaver - den spesifiserer at kun artikler i denne lokasjonen i hierarkiet skal vises.  Jokertegn kan benyttes s&aring; du ogs&aring; kan spesifisere foreldre/barn relasjoner. F.eks. {Products hierarchy=&#039;trucks*&#039;} vil lage en sammendragsrapport med alle trucks, inkludert barna i hierarkiet.  P&aring; samme m&aring;te, {Products hierarchy=&#039;*trucks&#039;} vil vise en sammendragsrapport med alle trucks og alle produkter tilh&oslash;rende enhver foreldre i hierarkiet. N&aring;r benyttet med hierarkihandlingen s&aring; kan denne parameter gi en liste med hierarkinavn for &aring; vise akkurat disse. F.eks. {Products action=hierarchy hierarchy=&#039;trucks,cars&#039;}';
 $lang['param_hierarchytemplate'] = 'Denne parameter spesifiserer malen som skal brukes for hierarki visning. Om ingen verdi er satt vil standard mal av den typen bli benyttet.';
 $lang['param_inline'] = 'Kun nyttig for s&oslash;k-handlingen, der denne parameteren spesifiserer at utdata for sammendragesvisningen skal vises inline';
-$lang['param_notpretty'] = 'Thie parameter specifies a comma separated list of actions to which pretty urls should not be generated.  i.e: notpretty=hierarchy,default will not generate pretty urls to hierarchy, or summary (default) actions, but will allow generation of pretty urls to detail views.  As a special vaue &quot;all&quot; can be used to specify that no pretty urls should be generated';
+$lang['param_notpretty'] = 'Denne parameter angir en kommaseparert liste over handlinger som vakre webadresser ikke b&oslash;r genereres for f.eks.: notpretty=hierarchy, default vil ikke generere vakre urler til hierarchy, eller summary (standard) handlingene, men vil tillate generering av vakre webadresser til detaljvisning. Som en spesiell verdi &quot;all&quot; kan brukes til &aring; angi at ingen pene urler skal genereres';
 $lang['param_pagelimit'] = 'Benyttet med <em>standard</em> handlingen vil denne parameter spesifisere hvor mange produkter som skal listes p&aring; hver side.';
 $lang['param_parent'] = 'Kan kun benyttes i <em>hierarchy</em> handlingen. Denne parameter spesifiserer hierarki id til start posisjonen i rapporten.';
-$lang['param_parents'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies a comma separated list of hierarchy names that specify to create numerous heirarchy trees from the specified location(s).  Hierarchy names must be unique, and not contain any special chars.';
+$lang['param_parents'] = 'Nyttig bare i <em>hierarchy</em> handlingen, angir denne parameteren en kommaseparert liste med hierarki navn som spesifiserer for oppretting en rekke hierarki tr&aelig;r fra den/de angitte plassering(ene). Hierarki navn m&aring; v&aelig;re unike, og ikke inneholde spesialtegn.';
 $lang['param_productid'] = 'Benyttet med detalj handlingen vil denne parameter indikere hvilket produkt som skal vises p&aring; siden.';
 $lang['param_productlist'] = 'Gjelder kun til standard (sammendrag) visning, hvor denne parameteren kan angi en kommaseparert liste med heltall produkt-IDer &aring; vise. Ingen paginering eller sortering utf&oslash;res da p&aring; disse verdiene. Andre spesifiserte filtreringsparametere, om dette er spesifisert for sammendragsvisningen, vil ogs&aring; ignoreres.';
 $lang['param_resultpage'] = 'Kun gyldig for s&oslash;k handlingen, hvor denne parameteren spesifiserer en side-id eller alias &aring; benytte for &aring; vise s&oslash;keresultatene';
@@ -386,13 +402,14 @@ $lang['value'] = 'Verdi';
 $lang['values'] = 'Verdier';
 $lang['view'] = 'Vis';
 $lang['viewable_fields'] = 'Velg brukerdefinerte felter som skal vises i tabellen';
+$lang['warn_edit_product_options'] = 'Hvert produkt valg m&aring; ha en unik streng. Om SKU/varenummer er p&aring;krevd s&aring; m&aring; det v&aelig;re unikt p&aring; tvers av hele systemet.';
 $lang['watermark_location'] = 'Vannmerke lokasjon';
 $lang['weight'] = 'Vekt';
 $lang['with_selected'] = 'Med valgte';
 $lang['yes'] = 'Ja';
 $lang['qca'] = 'P0-536849115-1307983495210';
-$lang['utma'] = '156861353.1400698784.1339530996.1339878866.1339882165.16';
-$lang['utmz'] = '156861353.1339530996.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.1410669460.1360334748.1363908655.1363990160.57';
+$lang['utmz'] = '156861353.1360334748.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353.3.10.1363990160';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
