@@ -29,6 +29,7 @@ $lang['areyousure'] = 'Weet u dit zeker?';
 $lang['areyousure_deleteproduct'] = 'Weet u zeker dat u dit product en alle bijbehorende informatie wilt verwijderen?';
 $lang['ascending'] = 'Oplopend';
 $lang['attribute_name'] = 'Atribuut Naam';
+$lang['attrib_text'] = 'Tekst';
 $lang['automatic'] = 'Automatisch';
 $lang['btn_setecomhandlers'] = 'Ecommerce Gebeurtenissen instellen';
 $lang['byhierarchytemplates'] = 'Hierarchie Rapport Sjablonen';
@@ -41,13 +42,15 @@ $lang['categorylisttemplates'] = 'Categorie Lijst Sjablonen';
 $lang['categorylisttemplate_addedit'] = 'Categorie Lijst Sjabloon toevoegen/aanpassen';
 $lang['centimeters'] = 'Centimeter';
 $lang['checkbox'] = 'Vinkvakje';
-$lang['confirm_copyattributes'] = 'Eventuele bestaande attributen voor dit product zullen worden verwijderd. Weet u zeker dat u door wilt gaan?';
+$lang['confirm_copyoptions'] = 'Any existing options for this item will be replaced. Are you sure you want to continue?';
 $lang['confirm_delete_hierarchy_node'] = 'Bent u zeker dat u deze node wilt verwijderen?  Elk product wat gebruik maakt van deze node zal niet meer onder een hi&euml;rarchie vallen.';
+$lang['confirm_deletealloptions'] = 'Are you sure you want to delete all options for this product?';
 $lang['confirm_import'] = 'Bent u zeker dat u dit wilt uitvoeren?\n\nVerkeerde instellingen of een verkeerd configuratiebestand kan het hele systeem in de war brengen. Wat resulteert in een niet werkende producten module.';
 $lang['copy'] = 'Kopie';
 $lang['copy_product'] = 'Kopieer dit item';
 $lang['copy_attrib_sets'] = 'Kopieer attributenset';
 $lang['copy_category'] = 'Categorie kopieren';
+$lang['copy_options_from'] = 'Kopieer alle opties van';
 $lang['createddate'] = 'Aangemaakt op';
 $lang['current_value'] = 'Huidige waarde';
 $lang['data'] = 'Data ';
@@ -55,6 +58,7 @@ $lang['default'] = 'Standaard';
 $lang['defaulttemplates'] = 'Standaard Sjablonen';
 $lang['default_template_notice'] = '<strong>Opmerking:</strong> De inhoud van deze tekstblokken worden gebruikt om de standaard waarden van een template op te slaan. Als u op de knop &quot;Voeg template toe&quot; klikt dan zullen deze standaard waarden in het nieuwe template worden opgenomen.';
 $lang['delete'] = 'Verwijderen';
+$lang['delete_all'] = 'Verwijder alles';
 $lang['delete_attribset'] = 'Attribuut verwijderen';
 $lang['delete_hierarchy_item'] = 'Verwijder Hierarchie Item';
 $lang['descending'] = 'Aflopend';
@@ -76,7 +80,10 @@ $lang['edit_attribsets_for'] = 'Attribuut Groep aanpasen voor';
 $lang['edit_attributes'] = 'Attribuut aanpassen';
 $lang['edit_category'] = 'Categorie aanpassen';
 $lang['edit_category_fields'] = 'Categorie Velden aanpassen';
-$lang['edit_hierarchy_item'] = 'Hierarchie Item aanpassen';
+$lang['edit_hierarochy_item'] = 'Edit Hierarchy Item';
+$lang['edit_option_notes'] = 'Edit Option Notes';
+$lang['edit_options'] = 'Edit Product Options';
+$lang['edit_product'] = 'Wijzig Item ';
 $lang['errors'] = 'Fouten';
 $lang['error_attribset_exists'] = 'Er bestaat al een attribuut met deze naam';
 $lang['error_dberror'] = 'Database fout';
@@ -85,11 +92,13 @@ $lang['error_fieldvalue_empty'] = 'De Veld Waarde mag niet leeg zijn';
 $lang['error_fileformat'] = 'File Format probleem';
 $lang['error_filenotfound'] = 'Bestand niet gevonden';
 $lang['error_fileopen'] = 'Probleem met openen van bestand %s';
+$lang['error_invalidparamcount'] = 'Invalid (or not matching) parameter count';
 $lang['error_invalidparent'] = 'Ongeldige Ouder (een hierarchie node kan niet zijn eigen ouder zijn)';
 $lang['error_invalid_name'] = 'De aangepaste veld waarde die u heeft ingevoerd klopt niet (er staan ook niet alfnumerieke karakters in)';
 $lang['error_invalid_value'] = 'Ongeldige waarde opgegeven';
 $lang['error_missingparam'] = 'Een benodigde parameter mist of is niet geldig';
 $lang['error_nameused'] = 'Een item met deze naam is al in gebruik';
+$lang['error_needtworows'] = 'A minimum of two rows is requried';
 $lang['error_nofieldtype'] = 'Selecteer a.u.b. een veldtype';
 $lang['error_noname'] = 'U moet een naam invoeren';
 $lang['error_onequantityfield'] = 'Er is slechts een veld met de hoeveelheid toegestaan';
@@ -99,8 +108,12 @@ $lang['error_product_aliasused'] = 'De genoemde alias is al in gebruik';
 $lang['error_product_nameused'] = 'Er bestaat al een product met deze naam';
 $lang['error_product_notfound'] = 'Het gevraagde product kan niet worden gevonden';
 $lang['error_product_skuused'] = 'Deze Uitlevereenheid is al in gebruik door een ander product';
+$lang['error_product_skuused_atrow'] = 'That SKU value at row %d is already in use by another item';
 $lang['error_price_adjustment'] = 'Ongeldige prijs aanpassing van item %s';
+$lang['erorr_qoh_negative_atrow'] = 'Quantity on hand cannot be negative at row %d';
 $lang['error_sku_required'] = 'Voer een unieke SKU in';
+$lang['error_sku_required_atrow'] = 'Please enter a unique SKU on row %d';
+$lang['error_text_empty_atrow'] = 'The text field at row %d cannot be empty';
 $lang['error_upload_failed'] = 'Upload mislukt: %s';
 $lang['exclude_categories'] = 'Sluit producten in de geselecteerde categori&euml;n uit van de resultaten';
 $lang['expire_six_months'] = 'Na zes maanden';
@@ -176,6 +189,9 @@ $lang['module_description'] = 'Een module voor het managen van een productcatalo
 $lang['move_down'] = 'Verschuif naar beneden';
 $lang['move_up'] = 'Verschuif naar boven';
 $lang['msg_eventhandlers_created'] = 'Gebeurtenishandlers gecree&euml;rd.';
+$lang['msg_optionscopied'] = 'Product options copied (but not saved yet)';
+$lang['msg_options_deleted'] = 'Product options deleted for product %d';
+$lang['msg_options_saved'] = 'Product options saved';
 $lang['msg_productcopied'] = 'Item successfully copied.  You are now editing the copy.  Any sku information in the item, and/or attributes has been cleared';
 $lang['name'] = 'Naam';
 $lang['needpermission'] = 'U heeft niet de vereiste rechten: %s';
@@ -184,15 +200,16 @@ $lang['nextpage'] = '>';
 $lang['no'] = 'Nee';
 $lang['nonamegiven'] = 'Er is geen naam ingevuld';
 $lang['none'] = 'Geen';
+$lang['notes'] = 'Opmerkingen';
 $lang['nothing_selectd'] = 'Niets geselecteerd';
 $lang['of'] = 'Van';
+$lang['ok'] = 'Ok&eacute;';
 $lang['operation_cancelled'] = 'Actie geannuleerd';
 $lang['operation_complete'] = 'Operatie uitgevoerd';
 $lang['page'] = 'Pagina';
 $lang['page_of'] = 'Pagina %s van %s';
 $lang['page_limit'] = 'Pagina Limiet';
 $lang['param_action'] = '
-
 Specify the behaviour of the module.  Possible values are:
 <ul>
   <li>hierarchy -- Display an item list by hierarchy</li>
@@ -208,26 +225,20 @@ Specify the behaviour of the module.  Possible values are:
 <li>ajax_propval - Return a json encoded list of property values matching the criteria specified.  This action is intended to be used via ajax, and should be called with the showtemplate=false parameter on the URL.</li>
 </ul> ';
 $lang['param_category'] = '
-
 When used in the <em>default</em> summary mode, this parameter, which should match the name of an existing category will be used to display only those items that are in that categoory. (a comma seperated list can be supplied).  This parameter can also be used with the categorylist action to limit the output to the specified item categories. ';
 $lang['param_categoryfield'] = 'Alleen van toepassing op de &quot;categorylist&quot; actie, deze parameter kan gebruikt worden om categori&euml;n te filteren op basis van de waarde van het categorieveld. Het werkt niet in combinatie met de &quot;category&quot; of de &quot;category_id&quot; parameters. De syntax van deze parameter is een kommagescheiden lijst met veldnamen en veldwaarden.  Bijvoorbeeld:  categorylist=&quot;veldnaam:waarde,veldnaam 2:waarde 2&quot;';
 $lang['param_categorylisttemplate'] = 'Useful only with the categorylist action, this parameter indicates the template that should be used for the display.  If no value is specified then the current default template of that type is used.';
 $lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist actions, this parameter indicates the template that should be used for the display of the category details.  This uses a category list template..  If no value is specified then the current default template of that type is used. ';
 $lang['param_detailpage'] = '
-
 This specifies the pageid or alias that should be used to display the detail report.  It can be used with the <em>default</em> or search actions.  This option is not compatible with pretty urls of any sort. ';
 $lang['param_detailtemplate'] = '
-
 This parameter specifies the template that should be used for the detail mode display.  If no value is specified, then the current default template of that type is used.  This parameter has no use when pretty urls are enabled. ';
 $lang['param_excludecat'] = 'Applicable only to the default (summary) view, this parameter will allow excluding products that are in a specific category from the result. A comma separated list of category names is allowed. This parameter can work in conjunction with the category parameter to provide a list of the products that are in this category, but not in that category ';
 $lang['param_field'] = '
-
 Used in the <em>fieldlist</em> and the <em>ajax_propval</em> actions. In the fieldlist action, this parameter is required to specify the name of a user defined property to create a list from.  In the ajax_propval action this parameter is used to specify which field to use to extract a list of values.  Any valid field names are accepted (though only text field and dropdown field names will work properly.  Additionally the special values ::name::, ::sku::, and ::alias:: can be specified to return values from the item name, sku and alias respectively. ';
 $lang['param_fieldval'] = '
-
 Used in the <em>default</em> and <em>ajax_propval</em> actions, this parameter allows specifying a field value to limit results by.  In the default value these special values are accepted: &amp;quot;::null::&amp;quot; &amp;quot;::notnull::&amp;quot;. In the ajax_propval action this field is expected to contain only a few letters, to indicate a small filter.  i.e: fieldval=b to return all field values that begin with the letter b. ';
 $lang['param_hierarchy'] = '
-
 Useed in the <em>default</em> and hierachy actions this parameter has two uses.  When used in the default (summary) action, this parameter specifies that only items in that location of the hierarchy should be displayed.  Wildcard character can be used so that you can specify parent/child relationships as well.  i.e {Products hierarchy=&#039;trucks*&#039;} will create a summary report of all trucks, including the children in the hierarchy.  Similarly, {Products hierarchy=&#039;*trucks&#039;} will display a summary report of all trucks, and all items beloging to any parent in the hierarchy.  A comma separated list of expressions can be supplied.  i.e: {Products action=hierarchy hierarchy=&#039;trucks,cars&#039;} ';
 $lang['param_hierarchytemplate'] = 'This parameter specifies the template that should be used for the hierarchy display. If no value is specified, then the current default template of that type is used. ';
 $lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline ';
@@ -247,7 +258,6 @@ $lang['param_sortorder'] = 'Specify the order of sorted fields in summary view.
   <li>desc -- Descending order</li>
 </ul>';
 $lang['param_sortby'] = '
-
 Applicable in the summary, categorylist or search actions, this parameter determines the sorting of the output.  Possible values are:
 <ul>
   <li><strong>item_name</strong></li>
@@ -400,12 +410,13 @@ $lang['value'] = 'Waarde';
 $lang['values'] = 'Waarden';
 $lang['view'] = 'Bekijk';
 $lang['viewable_fields'] = 'Selecteer velden om in het tabel te tonen';
+$lang['warn_edit_product_options'] = 'Each product option must have a unique string.  If SKU is required then it must be unique across the entire system.';
 $lang['watermark_location'] = 'Plaats Watermerk';
 $lang['weight'] = 'Gewicht';
 $lang['with_selected'] = 'Met geselecteerden';
 $lang['yes'] = 'Ja';
-$lang['utma'] = '156861353.345096645.1341849918.1341849918.1341849918.1';
-$lang['utmz'] = '156861353.1341849918.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/search.php|utmcmd=referral';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.679304078.1356693526.1356795711.1356811621.4';
+$lang['utmz'] = '156861353.1356693526.1.1.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/files/6';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
