@@ -100,8 +100,10 @@ class hierarchy_ops
   public static function get_hierarchy_info($hierarchy_id)
   {
     $allinfo = self::get_all_hierarchy_info();
-    if( is_array($allinfo) && count($allinfo) && isset($allinfo[$hierarchy_id]) ) {
-      return $allinfo[$hierarchy_id];
+    if( is_array($allinfo) && count($allinfo) ) {
+      if( isset($allinfo[$hierarchy_id]) ) {
+	return $allinfo[$hierarchy_id];
+      }
     }
   }
 
