@@ -46,29 +46,29 @@ final class product_ops
 
   static public function set_product($product)
   {
-    if( !is_array($product) || !isset($product['id']) ) return;
-    if( !is_array(self::$_product_cache) ) self::$_product_cache = array();
-    self::$_product_cache[$product['id']] = $product;
+    if( !isset($product['id']) || !isset($product['name']) ) {
+      self::$_product_cache[$product['id']] = $product;
+    }
   }
 
-  static public function get_product($product_id)
+  static public function get_product($product_id,$anystatus = FALSE)
   {
+    $product_it = (int)$product_id;
     if( is_array(self::$_product_cache) && isset(self::$_product_cache[$product_id]) ) {
       return self::$_product_cache[$product_id];
     }
 
     $query = new products_query();
-    $query['product_id'] = $product_id;
+    $query['product_id'] = (int)$product_id;
+    if( $anystatus ) $query['status'] = '*';
     $results = new products_resultset($query);
     if( $results->RecordCount() > 1 ) {
       throw new Exception('INTERNAL ERROR: More than one product with the id '.$product_id);
     }
-    
+
+    $product = $results->get_product(FALSE,TRUE);
     if( !is_array(self::$_product_cache) ) self::$_product_cache = array();
-    self::$_product_cache[$product_id] = $results->fields;
-    if( $product_id != $results->fields['id'] ) {
-      throw new Exception('INTERNAL ERROR: query did not return information for '.$product_id);
-    }
+    self::$_product_cache[$product_id] = $product;
     return self::$_product_cache[$product_id];
   }
 
@@ -100,15 +100,13 @@ final class product_ops
     // convert into "name | name | name | name";
     $tmp = explode('.',$str);
     $tmp2 = array();
-    foreach( $tmp as $one )
-      {
-	$tmp2[] = trim(trim($one,'"'));
-      }
+    foreach( $tmp as $one ) {
+      $tmp2[] = trim(trim($one,'"'));
+    }
     $tmp3 = implode(' | ',$tmp2);
 
     $db = cmsms()->GetDb();
-    $query = 'SELECT id FROM '.cms_db_prefix().'module_products_hierarchy
-               WHERE long_name = ?';
+    $query = 'SELECT id FROM '.cms_db_prefix().'module_products_hierarchy WHERE long_name = ?';
     $tmp = $db->GetOne($query,array($tmp3));
     if( !$tmp ) return FALSE;
     return TRUE;
@@ -118,24 +116,20 @@ final class product_ops
   public static function check_sku_used($sku,$productid = '',$productonly = false)
   {
     $db = cmsms()->GetDb();
-    $query = 'SELECT id FROM '.cms_db_prefix().'module_products
-               WHERE sku = ?';
+    $query = 'SELECT id FROM '.cms_db_prefix().'module_products WHERE sku = ?';
     $parms = array($sku);
-    if( !empty($productid) )
-      {
-	$query .= ' AND id != ?';
-	$parms[] = $productid;
-      }
+    if( !empty($productid) ) {
+      $query .= ' AND id != ?';
+      $parms[] = $productid;
+    }
     $tmp = $db->GetOne($query,$parms);
     if( $tmp ) return TRUE;
 
-    if( !$productonly )
-      {
-	$query = 'SELECT id FROM '.cms_db_prefix().'module_products_attributes
-                   WHERE sku = ?';
-	$tmp = $db->GetOne($query,array($sku));
-	if( $tmp ) return TRUE;
-      }
+    if( !$productonly ) {
+      $query = 'SELECT id FROM '.cms_db_prefix().'module_products_attribs WHERE sku = ?';
+      $tmp = $db->GetOne($query,array($sku));
+      if( $tmp ) return TRUE;
+    }
 
     return FALSE;
   }
@@ -148,13 +142,11 @@ final class product_ops
 
     $parms = array();
     $parms[] = $alias;
-    $query = 'SELECT id FROM '.cms_db_prefix().'module_products
-               WHERE alias = ?';
-    if( !empty($productid) )
-      {
-	$query .= 'AND id != ?';
-	$parms[] = (int)$productid;
-      }
+    $query = 'SELECT id FROM '.cms_db_prefix().'module_products WHERE alias = ?';
+    if( !empty($productid) ) {
+      $query .= 'AND id != ?';
+      $parms[] = (int)$productid;
+    }
     $tmp = $db->GetOne($query,$parms);
     if( !$tmp ) return FALSE;
     return TRUE;
@@ -166,13 +158,12 @@ final class product_ops
     $str = munge_string_to_url($product_name);
     $postfix = '';
     
-    while( $postfix < 1000 )
-      {
-	$alias = $str.$postfix;
-	if( !self::check_alias_used($alias) ) return $alias;
-	if( $postfix == '' ) $postfix = 1;
-	$postfix++;
-      }
+    while( $postfix < 1000 ) {
+      $alias = $str.$postfix;
+      if( !self::check_alias_used($alias) ) return $alias;
+      if( $postfix == '' ) $postfix = 1;
+      $postfix++;
+    }
 
     return FALSE;
   }
@@ -187,87 +178,63 @@ final class product_ops
     $db = cmsms()->GetDB();
     
     $usereturnid = true;    
-    if( $returnid == -1 )
-      {
-	global $gCms;
-	$contentops = $gCms->GetContentOperations();
-	$returnid = $contentops->GetDefaultContent();
-      }
+    if( $returnid == -1 ) {
+      global $gCms;
+      $contentops = $gCms->GetContentOperations();
+      $returnid = $contentops->GetDefaultContent();
+    }
     $dfltreturnid = $module->GetPreference('detailpage',-1);
-    if( $dfltreturnid == $returnid || $returnid == '' )
-      {
-	$usereturnid = false;
-	$returnid = $dfltreturnid;
-      }
+    if( $dfltreturnid == $returnid || $returnid == '' ) {
+      $usereturnid = false;
+      $returnid = $dfltreturnid;
+    }
 
     $pretty_url = $module->GetPreference('urlprefix',$module->GetName());
     $done = false;
-    if( $module->GetPreference('usehierpathurls',0) && !empty($product['alias']) && ($product['hier_id'] > 0) )
-      {
-	$hier_id = self::get_product_hierarchy_id($pid);
-	if( $hier_id )
-	  {
-	    $tmp = hierarchy_ops::get_hierarchy_info($hier_id);
-	    if( $tmp )
-	      {
-		$tmp2 = explode(' | ',$tmp['long_name']);
-		for( $i = 0; $i < count($tmp2); $i++ )
-		  {
-		    $tmp2[$i] = munge_string_to_url($tmp2[$i]);
-		  }
-		$path = implode('/',$tmp2);
-		
-		$pretty_url .= '/details';
-
-		if( $usereturnid )
-		  {
-		    $pretty_url .= "/$returnid";
-		  }
-
-		if( !empty($path) )
-		  {
-		    $pretty_url .= "/$path";
-		  }
-		
-		$pretty_url .= "/".$product['alias'];
-		$done = true;
-	      }
+    if( $module->GetPreference('usehierpathurls',0) && !empty($product['alias']) && ($product['hier_id'] > 0) ) {
+      $hier_id = self::get_product_hierarchy_id($pid);
+      if( $hier_id ) {
+	$tmp = hierarchy_ops::get_hierarchy_info($hier_id);
+	if( $tmp ) {
+	  $tmp2 = explode(' | ',$tmp['long_name']);
+	  for( $i = 0; $i < count($tmp2); $i++ ) {
+	    $tmp2[$i] = munge_string_to_url($tmp2[$i]);
 	  }
+	  $path = implode('/',$tmp2);
+
+	  $pretty_url .= '/details';
+
+	  if( $usereturnid ) $pretty_url .= "/$returnid";
+	  if( !empty($path) ) $pretty_url .= "/$path";
+
+	  $pretty_url .= "/".$product['alias'];
+	  $done = true;
+	}
       }
+    }
 
-    if( !$done )
-      {
-	$pretty_url .= "/$pid";
-	if( $usereturnid )
-	  {
-	    $pretty_url .= "/$returnid";
-	  }
-	$alias = $product['alias'];
-	if( empty($alias) )
-	  {
-	    $alias = $module->make_alias($product['product_name']);
-	  }
-	$pretty_url .= "/$alias";
-      }
+    if( !$done ) {
+      $pretty_url .= "/$pid";
+      if( $usereturnid ) $pretty_url .= "/$returnid";
+      $alias = $product['alias'];
+      if( empty($alias) ) $alias = $module->make_alias($product['product_name']);
+      $pretty_url .= "/$alias";
+    }
     return $pretty_url;
   }
 
 
   public static function get_product_hierarchy_id($productid)
   {
-    if( !is_array(self::$_prodhier) || !isset(self::$_prodhier[$productid]) )
-      {
-	$db = cmsms()->GetDb();
-	$query = 'SELECT hierarchy_id FROM '.cms_db_prefix().'module_products_prodtohier
-              WHERE product_id = ? LIMIT 1';
-	$hier_id = $db->GetOne($query,array($productid));
-	if( $hier_id <= 0 ) return FALSE;
-	if( !is_array(self::$_prodhier) )
-	  {
-	    self::$_prodhier = array();
-	  }
-	self::$_prodhier[$productid] = $hier_id;
-      }
+    if( !is_array(self::$_prodhier) || !isset(self::$_prodhier[$productid]) ) {
+      $db = cmsms()->GetDb();
+      $query = 'SELECT hierarchy_id FROM '.cms_db_prefix().'module_products_prodtohier
+                WHERE product_id = ? LIMIT 1';
+      $hier_id = $db->GetOne($query,array($productid));
+      if( $hier_id <= 0 ) return FALSE;
+      if( !is_array(self::$_prodhier) ) self::$_prodhier = array();
+      self::$_prodhier[$productid] = $hier_id;
+    }
     return self::$_prodhier[$productid];
   }
 
@@ -276,10 +243,7 @@ final class product_ops
   public static function get_product_hierarchy_path($productid)
   {
     $hier_id = self::get_product_hierarchy_id($productid);
-    if( $hier_id )
-      {
-	return hierarchy_ops::get_hierarchy_path($hier_id);
-      }
+    if( $hier_id ) return hierarchy_ops::get_hierarchy_path($hier_id);
   }
 
 
@@ -297,46 +261,34 @@ final class product_ops
     $result = array();
     $mod = cms_utils::get_module('Products');
     
-    if ($attr != 'product')
-      {
-	return $result;
-      }
-
-    if( $mod->GetPreference('use_detailpage_for_search',0) )
-      {
-	$returnid = '';
-      }
+    if ($attr != 'product') return $result;
+    if( $mod->GetPreference('use_detailpage_for_search',0) ) $returnid = '';
 
     $db = $mod->GetDb();
-    $q = "SELECT product_name FROM ".cms_db_prefix()."module_products WHERE
-			      id = ?";
+    $q = "SELECT product_name FROM ".cms_db_prefix()."module_products WHERE id = ?";
     $dbresult = $db->Execute( $q, array( $productid ) );
-    if ($dbresult)
-      {
-	$row = $dbresult->FetchRow();
-	
-	//0 position is the prefix displayed in the list results.
-	$result[0] = $mod->GetFriendlyName();
-	
-	//1 position is the title
-	$result[1] = $row['product_name'];
-	
-	//2 position is the URL to the title.
-	$prettyurl = self::pretty_url($productid,$returnid);
-	$result[2] = $mod->CreateLink('cntnt01', 'details', $returnid, '', array('productid' => $productid) ,
-				      '', true, false, '', true, $prettyurl);
-      }
-    
+    if ($dbresult) {
+      $row = $dbresult->FetchRow();
+
+      //0 position is the prefix displayed in the list results.
+      $result[0] = $mod->GetFriendlyName();
+
+      //1 position is the title
+      $result[1] = $row['product_name'];
+
+      //2 position is the URL to the title.
+      $prettyurl = self::pretty_url($productid,$returnid);
+      $result[2] = $mod->CreateLink('cntnt01', 'details', $returnid, '', array('productid' => $productid) ,
+				    '', true, false, '', true, $prettyurl);
+    }
+
     return $result;
   }
-	
+
 
   public static function get_currency_symbol()
   {
-    if( class_exists('cg_ecomm') )
-      {
-	return cg_ecomm::get_currency_symbol();
-      }
+    if( class_exists('cg_ecomm') ) return cg_ecomm::get_currency_symbol();
     $mod = cms_utils::get_module('Products');
     return $mod->GetPreference('products_currencysymbol','$');
   }
@@ -344,10 +296,7 @@ final class product_ops
 
   public static function get_weight_units()
   {
-    if( class_exists('cg_ecomm') )
-      {
-	return cg_ecomm::get_weight_units();
-      }
+    if( class_exists('cg_ecomm') ) return cg_ecomm::get_weight_units();
     $mod = cms_utils::get_module('Products');
     return $mod->GetPreference('products_weightunits','kg');
   }
@@ -355,25 +304,21 @@ final class product_ops
   
   public static function get_length_units()
   {
-    if( class_exists('cg_ecomm') )
-      {
-	return cg_ecomm::get_length_units();
-      }
+    if( class_exists('cg_ecomm') ) return cg_ecomm::get_length_units();
     $mod = cms_utils::get_module('Products');
     return $mod->GetPreference('products_lengthunits','kg');
   }
 
-  
+
   public static function get_fields()
   {
-    if( !is_array(self::$_fielddefs) )
-      {
-	global $gCms;
-	$db = $gCms->GetDb();
-	
-	$query = 'SELECT * FROM '.cms_db_prefix().'module_products_fielddefs ORDER BY item_order';
-	self::$_fielddefs = $db->GetArray($query);
-      }
+    if( !is_array(self::$_fielddefs) ) {
+      global $gCms;
+      $db = $gCms->GetDb();
+
+      $query = 'SELECT * FROM '.cms_db_prefix().'module_products_fielddefs ORDER BY item_order';
+      self::$_fielddefs = $db->GetArray($query);
+    }
     return self::$_fielddefs;
   }
 
@@ -384,47 +329,18 @@ final class product_ops
     if( !is_array($tmp) ) return;
 
     $result = array();
-    for( $i = 0; $i < count($tmp); $i++ )
-      {
-	if( $type == '' || $tmp[$i]['type'] == $type )
-	  {
-	    $result[$tmp[$i]['id']] = $tmp[$i]['prompt'];
-	  }
+    for( $i = 0; $i < count($tmp); $i++ ) {
+      if( $type == '' || $tmp[$i]['type'] == $type ) {
+	$result[$tmp[$i]['id']] = $tmp[$i]['prompt'];
       }
+    }
     return $result;
   }
 
 
   public static function get_product_attributes_full($product_id)
   {
-    $db = cmsms()->GetDb();
-    $data = array();
-
-    $query = 'SELECT * FROM '.cms_db_prefix().'module_products_attribsets
-              WHERE product_id = ?';
-    $tmp = $db->GetArray($query,array($product_id));	
-
-    $tmp2 = cge_array::extract_field($tmp,'attrib_set_id');
-    $q2 = 'SELECT * FROM '.cms_db_prefix().'module_products_attributes
-            WHERE attrib_set_id IN ('.implode(',',$tmp2).') ORDER BY attrib_set_id ASC';
-    $tmp3 = $db->GetArray($q2);
-
-    for( $i = 0; $i < count($tmp); $i++ )
-      {
-	$row =& $tmp[$i];
-
-	$attribs = array();
-	for( $j = 0; $j < count($tmp3); $j++ )
-	  {
-	    $row2 =& $tmp3[$j];
-	    if( $row2['attrib_set_id'] < $row['attrib_set_id'] ) continue;
-	    if( $row2['attrib_set_id'] > $row['attrib_set_id'] ) break;
-
-	    $attribs[$row2['attrib_text']] = $row2;
-	  }
-	$data[$row['attrib_set_name']] = $attribs;
-      }
-
+    $data = products_attrib::load_by_product($product_id);
     if( !count($data) ) return false;
     return $data;
   }
@@ -434,4 +350,4 @@ final class product_ops
 #
 # EOF
 #
-?>
+?>
\ No newline at end of file
