@@ -692,15 +692,7 @@ final class productsCsvImporter
     // get attributes
     // insert them.
     if( $is_update && $this->_getPolicyValue('clearattribs') ) {
-      $query = 'SELECT attrib_set_id FROM '.cms_db_prefix().'module_products_attribsets
-                WHERE product_id = ?';
-      $tmp = $db->GetCol($query,array($product_id));
-      
-      $query = 'DELETE FROM '.cms_db_prefix().'module_products_attributes
-                WHERE attrib_set_id IN ('.implode(',',$tmp).')';
-      $db->Execute($query);
-
-      $query = 'DELETE FROM '.cms_db_prefix().'module_products_attribsets
+      $query = 'DELETE FROM '.cms_db_prefix().'module_products_attribs
                 WHERE product_id = ?';
       $db->Execute($query,array($product_id));
     }
@@ -710,39 +702,25 @@ final class productsCsvImporter
       foreach( $attribs as $one ) {
 	$one = trim($one);
 	$one = trim($one,'"\'');
-	if( strstr($one,':') === FALSE ) continue;
-	list($set,$attr,$adj,$sku) = explode(':',$one);
-	$set = trim($set,'"\'');
-	$set = trim($set);
+	list($attr,$adj,$sku,$qoh) = explode(':',$one);
 	$attr = trim($attr,'"\'');
 	$attr = trim($attr);
 	$adj = trim($adj,'"\'');
 	$adj = trim($adj);
 	$sku = trim($sku,'"\'');
 	$sku = trim($sku);
+	$qoh = trim($qoh,'"\'');
+	$qoh = trim($qoh);
+	$qoh = (int)$qoh;
 	
-	if( empty($set) || empty($attr) ) continue;
+	if( empty($attr) ) continue;
 	
-	// add the attribute set
-	$fquery = 'SELECT attrib_set_id FROM '.cms_db_prefix().'module_products_attribsets
-                   WHERE product_id = ? AND attrib_set_name = ?';
-	$t_id = $db->GetOne($fquery,array($product_id,$set));
-	if( !$t_id ) {
-	  $squery = 'INSERT INTO '.cms_db_prefix().'module_products_attribsets
-                   (product_id, attrib_set_name) VALUES (?,?)';
-	  $db->Execute($squery,array($product_id,$set));
-	  $t_id = $db->Insert_ID();
-	}
-
 	// add the attribute value
-	$fquery = 'SELECT attrib_id FROM '.cms_db_prefix().'module_products_attributes
-                   WHERE attrib_set_id = ? AND attrib_text = ?';
-	$attr_id = $db->GetOne($fquery,array($t_id,$attr));
 	if( !$attr_id ) {
-	  $query = 'INSERT INTO '.cms_db_prefix().'module_products_attributes
-                    (attrib_set_id,attrib_text,attrib_adjustment,sku)
-                    VALUES (?,?,?,?)';
-	  $db->Execute($query,array($t_id,$attr,$adj,$sku));
+	  $query = 'INSERT INTO '.cms_db_prefix().'module_products_attribs
+                    (product_id,text,adjustment,sku,qoh)
+                    VALUES (?,?,?,?,?)';
+	  $db->Execute($query,array($product_id,$attr,$adj,$sku,$qoh));
 	}
       
       } // foreach
