@@ -71,6 +71,23 @@ final class products_resultset
 	  $where[] = 'C.id = ?';
 	  $qparms[] = $obj['product_id'];
 	}
+	else if( isset($obj['alias']) && $obj['alias'] != '' ) {
+	  $where[] = 'C.alias = ?';
+	  $qparms[] = $obj['alias'];
+	}
+	else if( isset($obj['sku']) && $obj['sku'] != '' ) {
+	  $where[] = 'C.sku = ?';
+	  $qparms[] = $obj['sku'];
+	}
+	if( isset($obj['optsku']) && $obj['optsku'] != '' ) {
+	  $subquery = 'SELECT DISTINCT product_id FROM '.cms_db_prefix().'module_products_attribs WHERE sku = ?';
+	  $subparms = array($obj['optsku']);
+	  
+	  $pid = $db->GetOne($subquery,$subparms);
+	  $where[] = 'C.id = ?';
+	  $qparms[] = $pid;
+	}
+
 	else if( isset($obj['productlist']) && $obj['productlist'] != '' ) {
 	  $tmp = $obj['productlist'];
 	  if( !is_array($tmp) ) {
@@ -97,13 +114,13 @@ final class products_resultset
 	}
 
     if( isset($obj['categoryid']) && $obj['categoryid'] != '' ) {
-      $joins[] = cms_db_prefix().'module_products_products_categories cc ON cc.product_id = C.id';
+      $joins[] = cms_db_prefix().'module_products_categories cc ON cc.product_id = C.id';
       $where[] = 'cc.category_id = ?';
       $qparms[] = $obj['categoryid'];
     }
 
 	if( isset($obj['hierarchy']) && $obj['hierarchy'] != '' ) {
-	  $subquery = 'SELECT DISTINCT id FROM '.cms_db_prefix().'module_products_hierarchy WHERE ';
+	  $subquery = 'SELECT DISTINCT id FROM '.cms_db_prefix().'module_products_hierarchy h WHERE ';
 	  $subparms = array();
 	  $tmp = explode(',',$obj['hierarchy']);
 	  $tmp2 = array();
@@ -141,11 +158,11 @@ final class products_resultset
 		foreach( $icats as $one ) {
 		  $one = trim($one);
 		  if( isset($ocats[$one]) ) {
-			$icatids[] = (int)$ocats[$one]['id'];
+			$icatids[] = (int)$ocats[$one]->id;
 		  }
 		}
 		if( count($icatids) ) {
-		  $joins[] = cms_db_prefix().'module_products_products_categories cc ON cc.product_id = c.id';
+		  $joins[] = cms_db_prefix().'module_products_product_categories cc ON cc.product_id = C.id';
 		  $where[] = 'cc.category_id IN ('.implode(',',$icatids).')';
 		}
       }
@@ -193,6 +210,24 @@ final class products_resultset
 	  }
 	}
 
+	$sortby = $obj['sortby'];
+	$sortorder = $obj['sortorder'];
+	if( startswith($sortby,'f:') ) {
+	  $sortby = substr($sortby,2);
+	  $fielddefs = product_utils::get_fielddefs(FALSE,TRUE,TRUE);
+	  if( is_array($fielddefs) && count($fielddefs) && isset($fielddefs[$sortby]) ) {
+		$joins[] = cms_db_prefix().'module_products_fieldvals FVS ON C.id = FVS.product_id AND FVS.fielddef_id = '.(int)$fielddefs[$sortby]->id;
+		$sortby = 'FVS.value';
+	  }
+	  else {
+		$sortby = 'product_name';
+	  }
+	}
+	else if( $sortby == 'random' ) {
+	  $sortby = 'RAND()';
+	  $sortorder = '';
+	}
+
 	//
 	// build the query now.
 	//
@@ -203,10 +238,10 @@ final class products_resultset
 	  $query .= ' WHERE '.implode(' AND ',$where);
 	}
 	if( $obj['sorttype'] == '' ) {
-	  $query .= ' ORDER BY '.$obj['sortby'].' '.$obj['sortorder'];
+	  $query .= ' ORDER BY '.$sortby.' '.$obj['sortorder'];
 	}
 	else {
-	  $query .= ' ORDER BY CAST('.$sortby.' AS '.$sorttype.') '.$sortorder;
+	  $query .= ' ORDER BY CAST('.$sortby.' AS '.$obj['sorttype'].') '.$obj['sortorder'];
 	}
 	
 	$startelement = 0;
@@ -258,32 +293,19 @@ final class products_resultset
 	if( !is_array($product_ids) || count($product_ids) == 0 ) return;
 
 	$db = cmsms()->GetDb();
-	$query = 'SELECT * FROM '.cms_db_prefix().'module_products_attribsets
-              WHERE product_id IN ('.implode(',',$product_ids).') ORDER BY product_id ASC,attrib_set_id ';
-	$attribsets = $db->GetArray($query);
-	if( !is_array($attribsets) || count($attribsets) == 0 ) return;
+	$query = 'SELECT * FROM '.cms_db_prefix().'module_products_attribs
+              WHERE product_id IN ('.implode(',',$product_ids).') ORDER BY product_id ASC, id ASC';
+	$attribs = $db->GetArray($query);
+	if( !is_array($attribs) || count($attribs) == 0 ) return;
 
-	$attribset_ids = cge_array::extract_field($attribsets,'attrib_set_id');
-	$query = 'SELECT * FROM '.cms_db_prefix().'module_products_attributes
-              WHERE attrib_set_id IN ('.implode(',',$attribset_ids).') ORDER BY attrib_set_id ASC';
-	$attributes = $db->GetArray($query);
-	
 	$this->_attribute_cache = array();
-	for( $i = 0; $i < count($attribsets); $i++ ) {
-	  $oneset =& $attribsets[$i];
+	for( $i = 0; $i < count($attribs); $i++ ) {
+	  $oneset =& $attribs[$i];
 	  $pid = $oneset['product_id'];
 	  if( !isset($this->_attribute_cache[$pid]) ) $this->_attribute_cache[$pid] = array();
 	  $data =& $this->_attribute_cache[$pid];
 
-	  $attribs = array();
-	  for( $j = 0; $j < count($attributes); $j++ ) {
-		$oneattrib =& $attributes[$j];
-		if( $oneattrib['attrib_set_id'] < $oneset['attrib_set_id'] ) continue;
-		if( $oneattrib['attrib_set_id'] > $oneset['attrib_set_id'] ) break;
-
-		$attribs[$oneattrib['attrib_text']] = $oneattrib;
-	  }
-	  $data[$oneset['attrib_set_name']] = $attribs;
+	  $data[] = $oneset;
 	}
   }
 
@@ -441,17 +463,17 @@ final class products_resultset
   }
 
   // return the full product (with fields, and attributes)
-  public function &get_product($bare = false)
+  public function &get_product($bare = false,$as_array = FALSE)
   {
 	$ret = null;
 	if( !$this->_rs ) return $ret;
 
-	product_ops::set_product($this->_rs->fields); // used by other stuff that requires a product... should minimize duplicate loads.
-	$onerow = cge_array::to_object($this->_rs->fields);	
+	$onerow = $this->_rs->fields;
 
+	$product_id = $this->_rs->fields['id'];
 	$config = cmsms()->GetConfig();
 	$module = cms_utils::get_module('Products');
-	$filedir = cms_join_path($config['uploads_path'],$module->GetName(),'product_'.$onerow->id);
+	$filedir = cms_join_path($config['uploads_path'],$module->GetName(),'product_'.$product_id);
 
 	// categories
 	if( is_array($this->_category_cache) && count($this->_category_cache) ) {
@@ -459,8 +481,8 @@ final class products_resultset
 	  $catarray = array();
 	  $catnamearray = array();
 	  for( $i = 0; $i < count($this->_category_cache); $i++ ) {
-		if( $this->_category_cache[$i]['product_id'] < $onerow->id ) continue;
-		if( $this->_category_cache[$i]['product_id'] > $onerow->id ) break;
+		if( $this->_category_cache[$i]['product_id'] < $product_id ) continue;
+		if( $this->_category_cache[$i]['product_id'] > $product_id ) break;
 
 		foreach( $cats as $onecat ) {
 		  if( $this->_category_cache[$i]['category_id'] != $onecat->id ) continue;
@@ -470,8 +492,8 @@ final class products_resultset
 		  $catarray[] = $entry;
 		}
 	  }
-	  $onerow->categories = $catarray;
-	  $onerow->catnamearray = $catnamearray;
+	  $onerow['categories'] = $catarray;
+	  $onerow['catnamearray'] = $catnamearray;
 	}
 
 	// fields
@@ -479,8 +501,8 @@ final class products_resultset
 	  $flddefs = product_utils::get_fielddefs(FALSE,TRUE);
 	  $fldarray = array();
 	  for( $i = 0; $i < count($this->_field_cache); $i++ ) {
-		if( $this->_field_cache[$i]['product_id'] < $onerow->id ) continue;
-		if( $this->_field_cache[$i]['product_id'] > $onerow->id ) break;
+		if( $this->_field_cache[$i]['product_id'] < $product_id ) continue;
+		if( $this->_field_cache[$i]['product_id'] > $product_id ) break;
 
 		foreach( $flddefs as $onedef ) {
 		  if( $this->_field_cache[$i]['fielddef_id'] != $onedef->id ) continue;
@@ -495,24 +517,26 @@ final class products_resultset
 			  $entry->thumbnail = 'thumb_'.$entry->value;
 			}
 			if( $entry->value && file_exists(cms_join_path($filedir,'preview_'.$entry->value)) ) {
-			  $entry->thumbnail = 'preview_'.$entry->value;
+			  $entry->preview = 'preview_'.$entry->value;
 			}
 		  }
 		  $entry->fielddef_id = $entry->id; // ??
 		  $fldarray[$entry->name] = $entry;
 		}
 	  }
-	  $onerow->fields = $fldarray;
+	  $onerow['fields'] = $fldarray;
 	}
 
 	// attributes
-	if( is_array($this->_attribute_cache) && isset($this->_attribute_cache[$onerow->id]) &&
-		is_array($this->_attribute_cache[$onerow->id]) &&
-		count($this->_attribute_cache[$onerow->id]) ) {
-	  $onerow->attributes = $this->_attribute_cache[$onerow->id];
-	  $onerow->attributes_full = $this->_attribute_cache[$onerow->id];
+	if( is_array($this->_attribute_cache) && isset($this->_attribute_cache[$product_id]) &&
+		is_array($this->_attribute_cache[$product_id]) &&
+		count($this->_attribute_cache[$product_id]) ) {
+	  $onerow['attributes'] = $this->_attribute_cache[$product_id];
 	}
 
+	product_ops::set_product($onerow);
+	if( $as_array ) return $onerow;
+	$onerow = cge_array::to_object($onerow);	
 	return $onerow;
   }
 
@@ -555,4 +579,4 @@ final class products_resultset
 #
 # EOF
 #
-?>
\ No newline at end of file
+?>
