@@ -76,10 +76,9 @@ $flds = "
 	product_id I NOT NULL,
 	category_id I NOT NULL,
 	create_date " . CMS_ADODB_DT . ",
-	modified_date " . CMS_ADODB_DT . "
-";
+	modified_date " . CMS_ADODB_DT;
 $sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_products_product_categories", 
-		$flds, $taboptarray);
+				  $flds, $taboptarray);
 $dict->ExecuteSQLArray($sqlarray);
 
 
@@ -114,8 +113,8 @@ $dict->ExecuteSQLArray($sqlarray);
 
 
 $flds = "
-	product_id I,
-	fielddef_id I,
+	product_id I KEY,
+	fielddef_id I KEY,
 	value X,
 	create_date " . CMS_ADODB_DT . ",
 	modified_date " . CMS_ADODB_DT . "
@@ -125,6 +124,8 @@ $sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_products_fieldvals",
 $dict->ExecuteSQLArray($sqlarray);
 
 
+/*
+ * not used any more, but here for reference temporarily.
 $flds = "
         attrib_set_id I KEY AUTO,
         product_id I KEY,
@@ -145,7 +146,18 @@ $flds = "
 $sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_products_attributes", 
 		$flds, $taboptarray);
 $dict->ExecuteSQLArray($sqlarray);
+*/
 
+$flds = "id I KEY AUTO,
+         product_id I KEY NOT NULL,
+         text C(255) KEY NOT NULL,
+         adjustment C(50),
+         sku  C(25),
+         qoh I,
+         notes X";
+$sqlarray = $dict->CreateTableSQL(cms_db_prefix().'module_products_attribs',
+				  $flds,$taboptarray);
+$dict->ExecuteSQLArray($sqlarray);
 
 $flds = "id I KEY AUTO,
          name C(255) NOT NULL,
